# Auto-generated by scripts/scaffold_roots.py for Gana 4
from . import registry


@registry.register("4.1", root="दिवु", meaning="क्रीडाविजिगीषाव्यवहारद्युतिस्तुतिमोदमदस्वप्नकान्तिगतिषु", gana="Divadi")
def root_4_1():
    """
    4.1 दिवु क्रीडाविजिगीषाव्यवहारद्युतिस्तुतिमोदमदस्वप्नकान्तिगतिषु 
    """
    return "दिवु"


@registry.register("4.2", root="षिवु", meaning="तन्तुसन्ताने", gana="Divadi")
def root_4_2():
    """
    4.2 षिवु तन्तुसन्ताने 
    """
    return "षिवु"


@registry.register("4.3", root="स्रिवु", meaning="गतिशोषणयोः", gana="Divadi")
def root_4_3():
    """
    4.3 स्रिवु गतिशोषणयोः 
    """
    return "स्रिवु"


@registry.register("4.4", root="ष्ठिवु", meaning="निरसने", gana="Divadi")
def root_4_4():
    """
    4.4 ष्ठिवु निरसने 
    """
    return "ष्ठिवु"


@registry.register("4.5", root="ष्णुसु", meaning="अदने", gana="Divadi")
def root_4_5():
    """
    4.5 ष्णुसु अदने 
    """
    return "ष्णुसु"


@registry.register("4.6", root="ष्णसु", meaning="निरसने", gana="Divadi")
def root_4_6():
    """
    4.6 ष्णसु निरसने 
    """
    return "ष्णसु"


@registry.register("4.7", root="क्नसु", meaning="ह्वरणदीप्त्योः", gana="Divadi")
def root_4_7():
    """
    4.7 क्नसु ह्वरणदीप्त्योः 
    """
    return "क्नसु"


@registry.register("4.8", root="व्युष", meaning="दाहे", gana="Divadi")
def root_4_8():
    """
    4.8 व्युष दाहे 
    """
    return "व्युष"


@registry.register("4.9", root="प्लुष", meaning="च", gana="Divadi")
def root_4_9():
    """
    4.9 प्लुष च 
    """
    return "प्लुष"


@registry.register("4.10", root="नृती", meaning="गात्रविक्षेपे", gana="Divadi")
def root_4_10():
    """
    4.10 नृती गात्रविक्षेपे 
    """
    return "नृती"


@registry.register("4.11", root="त्रसी", meaning="उद्वेगे", gana="Divadi")
def root_4_11():
    """
    4.11 त्रसी उद्वेगे 
    """
    return "त्रसी"


@registry.register("4.12", root="कुथ", meaning="पूतीभावे", gana="Divadi")
def root_4_12():
    """
    4.12 कुथ पूतीभावे 
    """
    return "कुथ"


@registry.register("4.13", root="पुथ", meaning="हिंसायाम्", gana="Divadi")
def root_4_13():
    """
    4.13 पुथ हिंसायाम् 
    """
    return "पुथ"


@registry.register("4.14", root="गुध", meaning="परिवेष्टने", gana="Divadi")
def root_4_14():
    """
    4.14 गुध परिवेष्टने 
    """
    return "गुध"


@registry.register("4.15", root="क्षिप", meaning="प्रेरणे", gana="Divadi")
def root_4_15():
    """
    4.15 क्षिप प्रेरणे 
    """
    return "क्षिप"


@registry.register("4.16", root="पुष्प", meaning="विकसने", gana="Divadi")
def root_4_16():
    """
    4.16 पुष्प विकसने 
    """
    return "पुष्प"


@registry.register("4.20", root="ष्टीम", meaning="आर्द्रीभावे", gana="Divadi")
def root_4_20():
    """
    4.20 ष्टीम आर्द्रीभावे 
    """
    return "ष्टीम"


@registry.register("4.21", root="व्रीड", meaning="चोदने लज्जायां च", gana="Divadi")
def root_4_21():
    """
    4.21 व्रीड चोदने लज्जायां च 
    """
    return "व्रीड"


@registry.register("4.22", root="इष", meaning="गतौ", gana="Divadi")
def root_4_22():
    """
    4.22 इष गतौ 
    """
    return "इष"


@registry.register("4.24", root="षुह", meaning="चक्यर्थे", gana="Divadi")
def root_4_24():
    """
    4.24 षुह चक्यर्थे 
    """
    return "षुह"


@registry.register("4.26", root="झृईष्", meaning="वयोहानौ", gana="Divadi")
def root_4_26():
    """
    4.26 झृईष् वयोहानौ 
    """
    return "झृईष्"


@registry.register("4.27", root="ओषूङ्", meaning="प्राणिप्रसवे", gana="Divadi")
def root_4_27():
    """
    4.27 ओषूङ् प्राणिप्रसवे 
    """
    return "ओषूङ्"


@registry.register("4.28", root="ओदूङ्", meaning="परितापे", gana="Divadi")
def root_4_28():
    """
    4.28 ओदूङ् परितापे 
    """
    return "ओदूङ्"


@registry.register("4.29", root="ओदीङ्", meaning="क्षये", gana="Divadi")
def root_4_29():
    """
    4.29 ओदीङ् क्षये 
    """
    return "ओदीङ्"


@registry.register("4.30", root="ओडीङ्", meaning="विहायसा गतौ", gana="Divadi")
def root_4_30():
    """
    4.30 ओडीङ् विहायसा गतौ 
    """
    return "ओडीङ्"


@registry.register("4.31", root="ओधीङ्", meaning="आधारे", gana="Divadi")
def root_4_31():
    """
    4.31 ओधीङ् आधारे 
    """
    return "ओधीङ्"


@registry.register("4.32", root="ओमीङ्", meaning="हिंसायाम्", gana="Divadi")
def root_4_32():
    """
    4.32 ओमीङ् हिंसायाम् 
    """
    return "ओमीङ्"


@registry.register("4.33", root="ओरीङ्", meaning="श्रवणे", gana="Divadi")
def root_4_33():
    """
    4.33 ओरीङ् श्रवणे 
    """
    return "ओरीङ्"


@registry.register("4.34", root="ओलीङ्", meaning="श्लेषणे", gana="Divadi")
def root_4_34():
    """
    4.34 ओलीङ् श्लेषणे 
    """
    return "ओलीङ्"


@registry.register("4.35", root="ओव्रीङ्", meaning="वृणोत्यर्थे", gana="Divadi")
def root_4_35():
    """
    4.35 ओव्रीङ् वृणोत्यर्थे 
    """
    return "ओव्रीङ्"


@registry.register("4.36", root="पीङ्", meaning="पाने", gana="Divadi")
def root_4_36():
    """
    4.36 पीङ् पाने 
    """
    return "पीङ्"


@registry.register("4.37", root="माङ्", meaning="माने", gana="Divadi")
def root_4_37():
    """
    4.37 माङ् माने 
    """
    return "माङ्"


@registry.register("4.38", root="ईङ्", meaning="गतौ", gana="Divadi")
def root_4_38():
    """
    4.38 ईङ् गतौ 
    """
    return "ईङ्"


@registry.register("4.39", root="प्रीङ्", meaning="प्रीतौ प्रीणने", gana="Divadi")
def root_4_39():
    """
    4.39 प्रीङ् प्रीतौ प्रीणने 
    """
    return "प्रीङ्"


@registry.register("4.40", root="शो", meaning="तनूकरणे", gana="Divadi")
def root_4_40():
    """
    4.40 शो तनूकरणे 
    """
    return "शो"


@registry.register("4.41", root="छो", meaning="छेदने", gana="Divadi")
def root_4_41():
    """
    4.41 छो छेदने 
    """
    return "छो"


@registry.register("4.42", root="षो", meaning="अन्तकर्मणि", gana="Divadi")
def root_4_42():
    """
    4.42 षो अन्तकर्मणि 
    """
    return "षो"


@registry.register("4.43", root="दो", meaning="अवखण्डने", gana="Divadi")
def root_4_43():
    """
    4.43 दो अवखण्डने 
    """
    return "दो"


@registry.register("4.44", root="जनी", meaning="प्रादुर्भावे", gana="Divadi")
def root_4_44():
    """
    4.44 जनी प्रादुर्भावे 
    """
    return "जनी"


@registry.register("4.45", root="दीपी", meaning="दीप्तौ", gana="Divadi")
def root_4_45():
    """
    4.45 दीपी दीप्तौ 
    """
    return "दीपी"


@registry.register("4.46", root="पूरी", meaning="आप्यायने", gana="Divadi")
def root_4_46():
    """
    4.46 पूरी आप्यायने 
    """
    return "पूरी"


@registry.register("4.47", root="तूरी", meaning="गतित्वरणहिंसनयोः", gana="Divadi")
def root_4_47():
    """
    4.47 तूरी गतित्वरणहिंसनयोः 
    """
    return "तूरी"


@registry.register("4.49", root="गूरी", meaning="हिंसागत्योः", gana="Divadi")
def root_4_49():
    """
    4.49 गूरी हिंसागत्योः 
    """
    return "गूरी"


@registry.register("4.51", root="जूरी", meaning="हिंसावयोहन्योः", gana="Divadi")
def root_4_51():
    """
    4.51 जूरी हिंसावयोहन्योः 
    """
    return "जूरी"


@registry.register("4.52", root="शूरी", meaning="हिंसास्तम्भनयोः हिंसस्तम्भयोः", gana="Divadi")
def root_4_52():
    """
    4.52 शूरी हिंसास्तम्भनयोः हिंसस्तम्भयोः 
    """
    return "शूरी"


@registry.register("4.53", root="चूरी", meaning="दाहे", gana="Divadi")
def root_4_53():
    """
    4.53 चूरी दाहे 
    """
    return "चूरी"


@registry.register("4.54", root="तप", meaning="ऐश्वेर्ये वा", gana="Divadi")
def root_4_54():
    """
    4.54 तप ऐश्वेर्ये वा 
    """
    return "तप"


@registry.register("4.55", root="वृतु", meaning="वरणे वर्तने", gana="Divadi")
def root_4_55():
    """
    4.55 वृतु वरणे वर्तने 
    """
    return "वृतु"


@registry.register("4.56", root="वावृतु", meaning="इति केचित्", gana="Divadi")
def root_4_56():
    """
    4.56 वावृतु इति केचित् 
    """
    return "वावृतु"


@registry.register("4.57", root="क्लिश", meaning="उपतापे", gana="Divadi")
def root_4_57():
    """
    4.57 क्लिश उपतापे 
    """
    return "क्लिश"


@registry.register("4.58", root="काश‍ृ", meaning="दीप्तौ", gana="Divadi")
def root_4_58():
    """
    4.58 काश‍ृ दीप्तौ 
    """
    return "काश‍ृ"


@registry.register("4.59", root="वाश‍ृ", meaning="शब्दे", gana="Divadi")
def root_4_59():
    """
    4.59 वाश‍ृ शब्दे 
    """
    return "वाश‍ृ"


@registry.register("4.60", root="मृष", meaning="तितिक्षायाम्", gana="Divadi")
def root_4_60():
    """
    4.60 मृष तितिक्षायाम् 
    """
    return "मृष"


@registry.register("4.61", root="ईशुचिर्", meaning="पूतीभावे", gana="Divadi")
def root_4_61():
    """
    4.61 ईशुचिर् पूतीभावे 
    """
    return "ईशुचिर्"


@registry.register("4.62", root="णह", meaning="बन्धने", gana="Divadi")
def root_4_62():
    """
    4.62 णह बन्धने 
    """
    return "णह"


@registry.register("4.63", root="रञ्ज", meaning="रागे", gana="Divadi")
def root_4_63():
    """
    4.63 रञ्ज रागे 
    """
    return "रञ्ज"


@registry.register("4.64", root="शप", meaning="आक्रोशे", gana="Divadi")
def root_4_64():
    """
    4.64 शप आक्रोशे 
    """
    return "शप"


@registry.register("4.65", root="पद", meaning="गतौ", gana="Divadi")
def root_4_65():
    """
    4.65 पद गतौ 
    """
    return "पद"


@registry.register("4.66", root="खिद", meaning="दैन्ये", gana="Divadi")
def root_4_66():
    """
    4.66 खिद दैन्ये 
    """
    return "खिद"


@registry.register("4.67", root="विद", meaning="सत्तायाम्", gana="Divadi")
def root_4_67():
    """
    4.67 विद सत्तायाम् 
    """
    return "विद"


@registry.register("4.68", root="बुध", meaning="अवगमने", gana="Divadi")
def root_4_68():
    """
    4.68 बुध अवगमने 
    """
    return "बुध"


@registry.register("4.69", root="युध", meaning="सम्प्रहारे", gana="Divadi")
def root_4_69():
    """
    4.69 युध सम्प्रहारे 
    """
    return "युध"


@registry.register("4.70", root="अनोरुध", meaning="कामे", gana="Divadi")
def root_4_70():
    """
    4.70 अनोरुध कामे 
    """
    return "अनोरुध"


@registry.register("4.71", root="अण", meaning="प्राणने", gana="Divadi")
def root_4_71():
    """
    4.71 अण प्राणने 
    """
    return "अण"


@registry.register("4.72", root="अन", meaning="इत्येके", gana="Divadi")
def root_4_72():
    """
    4.72 अन इत्येके 
    """
    return "अन"


@registry.register("4.73", root="मन", meaning="ज्ञाने", gana="Divadi")
def root_4_73():
    """
    4.73 मन ज्ञाने 
    """
    return "मन"


@registry.register("4.74", root="युज", meaning="समाधौ", gana="Divadi")
def root_4_74():
    """
    4.74 युज समाधौ 
    """
    return "युज"


@registry.register("4.75", root="सृज", meaning="विसर्गे", gana="Divadi")
def root_4_75():
    """
    4.75 सृज विसर्गे 
    """
    return "सृज"


@registry.register("4.76", root="लिश", meaning="अल्पीभावे", gana="Divadi")
def root_4_76():
    """
    4.76 लिश अल्पीभावे 
    """
    return "लिश"


@registry.register("4.78", root="व्यध", meaning="ताडने", gana="Divadi")
def root_4_78():
    """
    4.78 व्यध ताडने 
    """
    return "व्यध"


@registry.register("4.79", root="पुष", meaning="पुष्टौ", gana="Divadi")
def root_4_79():
    """
    4.79 पुष पुष्टौ 
    """
    return "पुष"


@registry.register("4.80", root="शुष", meaning="शोषणे", gana="Divadi")
def root_4_80():
    """
    4.80 शुष शोषणे 
    """
    return "शुष"


@registry.register("4.81", root="तुष", meaning="प्रीतौ", gana="Divadi")
def root_4_81():
    """
    4.81 तुष प्रीतौ 
    """
    return "तुष"


@registry.register("4.82", root="दुष", meaning="वैकृत्ये", gana="Divadi")
def root_4_82():
    """
    4.82 दुष वैकृत्ये 
    """
    return "दुष"


@registry.register("4.83", root="श्लिष", meaning="आलिङ्गने", gana="Divadi")
def root_4_83():
    """
    4.83 श्लिष आलिङ्गने 
    """
    return "श्लिष"


@registry.register("4.84", root="शक", meaning="विभाषितो मर्षणे", gana="Divadi")
def root_4_84():
    """
    4.84 शक विभाषितो मर्षणे 
    """
    return "शक"


@registry.register("4.85", root="ष्विदा", meaning="गात्रप्रक्षरणे", gana="Divadi")
def root_4_85():
    """
    4.85 ष्विदा गात्रप्रक्षरणे 
    """
    return "ष्विदा"


@registry.register("4.86", root="क्रुध", meaning="क्रोधे कोपे", gana="Divadi")
def root_4_86():
    """
    4.86 क्रुध क्रोधे कोपे 
    """
    return "क्रुध"


@registry.register("4.87", root="क्षुध", meaning="बुभुक्षायाम्", gana="Divadi")
def root_4_87():
    """
    4.87 क्षुध बुभुक्षायाम् 
    """
    return "क्षुध"


@registry.register("4.88", root="शुध", meaning="शौचे", gana="Divadi")
def root_4_88():
    """
    4.88 शुध शौचे 
    """
    return "शुध"


@registry.register("4.89", root="षिधु", meaning="संराद्धौ", gana="Divadi")
def root_4_89():
    """
    4.89 षिधु संराद्धौ 
    """
    return "षिधु"


@registry.register("4.90", root="रध", meaning="हिंसासंराद्ध्योः", gana="Divadi")
def root_4_90():
    """
    4.90 रध हिंसासंराद्ध्योः 
    """
    return "रध"


@registry.register("4.91", root="णश", meaning="अदर्शने", gana="Divadi")
def root_4_91():
    """
    4.91 णश अदर्शने 
    """
    return "णश"


@registry.register("4.92", root="तृप", meaning="प्रीणने", gana="Divadi")
def root_4_92():
    """
    4.92 तृप प्रीणने 
    """
    return "तृप"


@registry.register("4.93", root="दृप", meaning="हर्षमोहनयोः", gana="Divadi")
def root_4_93():
    """
    4.93 दृप हर्षमोहनयोः 
    """
    return "दृप"


@registry.register("4.94", root="द्रुह", meaning="जिघांसायाम्", gana="Divadi")
def root_4_94():
    """
    4.94 द्रुह जिघांसायाम् 
    """
    return "द्रुह"


@registry.register("4.95", root="मुह", meaning="वैचित्त्ये", gana="Divadi")
def root_4_95():
    """
    4.95 मुह वैचित्त्ये 
    """
    return "मुह"


@registry.register("4.96", root="ष्णुह", meaning="उद्गिरणे", gana="Divadi")
def root_4_96():
    """
    4.96 ष्णुह उद्गिरणे 
    """
    return "ष्णुह"


@registry.register("4.97", root="ष्णिह", meaning="प्रीतौ", gana="Divadi")
def root_4_97():
    """
    4.97 ष्णिह प्रीतौ 
    """
    return "ष्णिह"


@registry.register("4.98", root="शमु", meaning="उपशमे", gana="Divadi")
def root_4_98():
    """
    4.98 शमु उपशमे 
    """
    return "शमु"


@registry.register("4.99", root="तमु", meaning="काङ्क्षायाम्", gana="Divadi")
def root_4_99():
    """
    4.99 तमु काङ्क्षायाम् 
    """
    return "तमु"


@registry.register("4.100", root="दमु", meaning="उपशमे", gana="Divadi")
def root_4_100():
    """
    4.100 दमु उपशमे 
    """
    return "दमु"


@registry.register("4.101", root="श्रमु", meaning="तपसि खेदे च", gana="Divadi")
def root_4_101():
    """
    4.101 श्रमु तपसि खेदे च 
    """
    return "श्रमु"


@registry.register("4.102", root="भ्रमु", meaning="अनवस्थाने", gana="Divadi")
def root_4_102():
    """
    4.102 भ्रमु अनवस्थाने 
    """
    return "भ्रमु"


@registry.register("4.103", root="क्षमू", meaning="सहने", gana="Divadi")
def root_4_103():
    """
    4.103 क्षमू सहने 
    """
    return "क्षमू"


@registry.register("4.104", root="क्लमु", meaning="ग्लानौ", gana="Divadi")
def root_4_104():
    """
    4.104 क्लमु ग्लानौ 
    """
    return "क्लमु"


@registry.register("4.105", root="मदी", meaning="हर्षे", gana="Divadi")
def root_4_105():
    """
    4.105 मदी हर्षे 
    """
    return "मदी"


@registry.register("4.106", root="असु", meaning="क्षेपने", gana="Divadi")
def root_4_106():
    """
    4.106 असु क्षेपने 
    """
    return "असु"


@registry.register("4.107", root="यसु", meaning="प्रयत्ने", gana="Divadi")
def root_4_107():
    """
    4.107 यसु प्रयत्ने 
    """
    return "यसु"


@registry.register("4.108", root="जसु", meaning="मोक्षने", gana="Divadi")
def root_4_108():
    """
    4.108 जसु मोक्षने 
    """
    return "जसु"


@registry.register("4.109", root="तसु", meaning="उपक्षये", gana="Divadi")
def root_4_109():
    """
    4.109 तसु उपक्षये 
    """
    return "तसु"


@registry.register("4.110", root="दसु", meaning="च", gana="Divadi")
def root_4_110():
    """
    4.110 दसु च 
    """
    return "दसु"


@registry.register("4.111", root="वसु", meaning="स्तम्भे", gana="Divadi")
def root_4_111():
    """
    4.111 वसु स्तम्भे 
    """
    return "वसु"


@registry.register("4.112", root="बसु", meaning="इत्येके बादिरित्येके", gana="Divadi")
def root_4_112():
    """
    4.112 बसु इत्येके बादिरित्येके 
    """
    return "बसु"


@registry.register("4.113", root="भसु", meaning="इति केचित्", gana="Divadi")
def root_4_113():
    """
    4.113 भसु इति केचित् 
    """
    return "भसु"


@registry.register("4.114", root="व्युष", meaning="विभागे", gana="Divadi")
def root_4_114():
    """
    4.114 व्युष विभागे 
    """
    return "व्युष"


@registry.register("4.115", root="व्युस", meaning="इत्येके", gana="Divadi")
def root_4_115():
    """
    4.115 व्युस इत्येके 
    """
    return "व्युस"


@registry.register("4.116", root="ब्युस", meaning="इत्यन्ये ओष्ठ्यादिर्दन्त्यन्तो ब्युस इत्यन्ये", gana="Divadi")
def root_4_116():
    """
    4.116 ब्युस इत्यन्ये ओष्ठ्यादिर्दन्त्यन्तो ब्युस इत्यन्ये 
    """
    return "ब्युस"


@registry.register("4.117", root="बुस", meaning="इत्यपरे अयकार बुस इत्यपरे", gana="Divadi")
def root_4_117():
    """
    4.117 बुस इत्यपरे अयकार बुस इत्यपरे 
    """
    return "बुस"


@registry.register("4.118", root="वुस", meaning="इति केचित्", gana="Divadi")
def root_4_118():
    """
    4.118 वुस इति केचित् 
    """
    return "वुस"


@registry.register("4.121", root="पुष", meaning="च", gana="Divadi")
def root_4_121():
    """
    4.121 पुष च 
    """
    return "पुष"


@registry.register("4.122", root="प्लुष", meaning="दाहे", gana="Divadi")
def root_4_122():
    """
    4.122 प्लुष दाहे 
    """
    return "प्लुष"


@registry.register("4.123", root="विस", meaning="प्रेरणे", gana="Divadi")
def root_4_123():
    """
    4.123 विस प्रेरणे 
    """
    return "विस"


@registry.register("4.124", root="बिस", meaning="इत्येके", gana="Divadi")
def root_4_124():
    """
    4.124 बिस इत्येके 
    """
    return "बिस"


@registry.register("4.125", root="कुस", meaning="संश्लेषणे श्लेषणे", gana="Divadi")
def root_4_125():
    """
    4.125 कुस संश्लेषणे श्लेषणे 
    """
    return "कुस"


@registry.register("4.126", root="कुश", meaning="इत्येके", gana="Divadi")
def root_4_126():
    """
    4.126 कुश इत्येके 
    """
    return "कुश"


@registry.register("4.127", root="कुंस", meaning="इत्यन्ये", gana="Divadi")
def root_4_127():
    """
    4.127 कुंस इत्यन्ये 
    """
    return "कुंस"


@registry.register("4.128", root="कुंश", meaning="इत्यपरे", gana="Divadi")
def root_4_128():
    """
    4.128 कुंश इत्यपरे 
    """
    return "कुंश"


@registry.register("4.129", root="बुस", meaning="उत्सर्गे", gana="Divadi")
def root_4_129():
    """
    4.129 बुस उत्सर्गे 
    """
    return "बुस"


@registry.register("4.130", root="मुस", meaning="खण्डने", gana="Divadi")
def root_4_130():
    """
    4.130 मुस खण्डने 
    """
    return "मुस"


@registry.register("4.131", root="मसी", meaning="परिमाने", gana="Divadi")
def root_4_131():
    """
    4.131 मसी परिमाने 
    """
    return "मसी"


@registry.register("4.132", root="समी", meaning="इत्येके", gana="Divadi")
def root_4_132():
    """
    4.132 समी इत्येके 
    """
    return "समी"


@registry.register("4.133", root="लुट", meaning="विलोडने", gana="Divadi")
def root_4_133():
    """
    4.133 लुट विलोडने 
    """
    return "लुट"


@registry.register("4.134", root="लुठ", meaning="इत्येके", gana="Divadi")
def root_4_134():
    """
    4.134 लुठ इत्येके 
    """
    return "लुठ"


@registry.register("4.135", root="उच", meaning="समवाये", gana="Divadi")
def root_4_135():
    """
    4.135 उच समवाये 
    """
    return "उच"


@registry.register("4.138", root="भ्रंशु", meaning="अधःपतने", gana="Divadi")
def root_4_138():
    """
    4.138 भ्रंशु अधःपतने 
    """
    return "भ्रंशु"


@registry.register("4.139", root="वृश", meaning="वरणे", gana="Divadi")
def root_4_139():
    """
    4.139 वृश वरणे 
    """
    return "वृश"


@registry.register("4.140", root="कृश", meaning="तनूकरणे", gana="Divadi")
def root_4_140():
    """
    4.140 कृश तनूकरणे 
    """
    return "कृश"


@registry.register("4.141", root="ञितृष", meaning="ञितृषा पिपासायाम्", gana="Divadi")
def root_4_141():
    """
    4.141 ञितृष ञितृषा पिपासायाम् 
    """
    return "ञितृष"


@registry.register("4.142", root="हृष", meaning="तुष्टौ", gana="Divadi")
def root_4_142():
    """
    4.142 हृष तुष्टौ 
    """
    return "हृष"


@registry.register("4.143", root="रुष", meaning="रोषे", gana="Divadi")
def root_4_143():
    """
    4.143 रुष रोषे 
    """
    return "रुष"


@registry.register("4.144", root="रिष", meaning="हिंसायाम्", gana="Divadi")
def root_4_144():
    """
    4.144 रिष हिंसायाम् 
    """
    return "रिष"


@registry.register("4.145", root="डिप", meaning="क्षेपे", gana="Divadi")
def root_4_145():
    """
    4.145 डिप क्षेपे 
    """
    return "डिप"


@registry.register("4.146", root="कुप", meaning="क्रोधे", gana="Divadi")
def root_4_146():
    """
    4.146 कुप क्रोधे 
    """
    return "कुप"


@registry.register("4.147", root="गुप", meaning="व्याकुलत्वे", gana="Divadi")
def root_4_147():
    """
    4.147 गुप व्याकुलत्वे 
    """
    return "गुप"


@registry.register("4.150", root="लुप", meaning="विमोहने", gana="Divadi")
def root_4_150():
    """
    4.150 लुप विमोहने 
    """
    return "लुप"


@registry.register("4.151", root="ष्टुप", meaning="समुच्छ्राये", gana="Divadi")
def root_4_151():
    """
    4.151 ष्टुप समुच्छ्राये 
    """
    return "ष्टुप"


@registry.register("4.152", root="ष्टूप", meaning="इत्येके", gana="Divadi")
def root_4_152():
    """
    4.152 ष्टूप इत्येके 
    """
    return "ष्टूप"


@registry.register("4.153", root="लुभ", meaning="गार्द्ध्ये गार्ध्न्ये", gana="Divadi")
def root_4_153():
    """
    4.153 लुभ गार्द्ध्ये गार्ध्न्ये 
    """
    return "लुभ"


@registry.register("4.154", root="क्षुभ", meaning="सञ्चलने", gana="Divadi")
def root_4_154():
    """
    4.154 क्षुभ सञ्चलने 
    """
    return "क्षुभ"


@registry.register("4.156", root="तुभ", meaning="हिंसायाम्", gana="Divadi")
def root_4_156():
    """
    4.156 तुभ हिंसायाम् 
    """
    return "तुभ"


@registry.register("4.157", root="क्लिदू", meaning="आद्रीभावे", gana="Divadi")
def root_4_157():
    """
    4.157 क्लिदू आद्रीभावे 
    """
    return "क्लिदू"


@registry.register("4.158", root="ञिमिदा", meaning="स्नेहने", gana="Divadi")
def root_4_158():
    """
    4.158 ञिमिदा स्नेहने 
    """
    return "ञिमिदा"


@registry.register("4.159", root="ञिक्ष्विदा", meaning="स्नेहनमोचनयोः", gana="Divadi")
def root_4_159():
    """
    4.159 ञिक्ष्विदा स्नेहनमोचनयोः 
    """
    return "ञिक्ष्विदा"


@registry.register("4.160", root="ऋधु", meaning="वृद्धौ", gana="Divadi")
def root_4_160():
    """
    4.160 ऋधु वृद्धौ 
    """
    return "ऋधु"


@registry.register("4.161", root="गृधु", meaning="अभिकाङ्क्षायाम्", gana="Divadi")
def root_4_161():
    """
    4.161 गृधु अभिकाङ्क्षायाम् 
    """
    return "गृधु"



"""
Piṅgala Chandas (Prosody / Meter) Analyzer.

Implements the algorithms from Piṅgala's Chandaḥśāstra (c. 200 BCE):
  - Laghu/Guru quantization of Sanskrit text
  - Prastāra enumeration (all 2^n meter patterns)
  - Naṣṭam (index → pattern)
  - Uddiṣṭam (pattern → index)
  - Meter identification (Gāyatrī, Anuṣṭubh, Triṣṭubh, Jagatī, …)

Works on both IAST (Roman) and Devanāgarī input.
"""

from typing import Dict, List, Optional, Tuple

__all__ = ["ChandasAnalyzer", "MeterResult"]


class MeterResult:
    """Result of a meter analysis."""

    def __init__(self, text: str, pattern: str) -> None:
        self.text = text
        self.pattern = pattern      # "0110…" (0=laghu, 1=guru)
        self.syllable_count = len(pattern)
        self.laghu_count = pattern.count("0")
        self.guru_count = pattern.count("1")
        self.decimal = int(pattern, 2) if pattern else 0
        self.meter_name = self._identify_meter()

    def _identify_meter(self) -> str:
        n = self.syllable_count
        if n == 0:
            return "Unknown"
        # pada-level identification (quarter-verse)
        if n == 6:
            return "Gāyatrī (6)"
        if n == 7:
            return "Uṣṇih (7)"
        if 7 <= n <= 8:
            return "Anuṣṭubh / Śloka (8)"
        if n == 9:
            return "Bṛhatī (9)"
        if n == 11:
            return "Triṣṭubh (11)"
        if n == 12:
            return "Jagatī (12)"
        return f"Unclassified ({n} syllables)"

    def __repr__(self) -> str:
        ratio = (
            f"{self.laghu_count}:{self.guru_count}"
            if self.guru_count
            else f"{self.laghu_count}:0"
        )
        return (
            f"MeterResult(meter={self.meter_name!r}, pattern={self.pattern!r}, "
            f"syllables={self.syllable_count}, L:G={ratio})"
        )


class ChandasAnalyzer:
    """
    Piṅgala-based prosodic analyzer for Sanskrit.

    >>> ch = ChandasAnalyzer()
    >>> r = ch.analyze("Dharmasya tattvam nihitam guhayam")
    >>> r.pattern
    '10110011'
    """

    # ── IAST vowel classification ────────────────────────────────────────────
    _SHORT_VOWELS_IAST = frozenset("aiuṛḷ")
    _LONG_VOWELS_IAST = frozenset(
        ["ā", "ī", "ū", "ṝ", "ḹ", "e", "ai", "o", "au",
         "A", "I", "U", "E", "O"]
    )
    _ANUSVARA_VISARGA = frozenset(["ṃ", "ḥ", "M", "H"])

    # ── Devanāgarī classification ───────────────────────────────────────────
    _SHORT_V_DEV = frozenset("अइउऋऌ")
    _LONG_V_DEV = frozenset("आईऊॠऌएऐओऔ")
    _SHORT_MATRA = frozenset("िुृ")
    _LONG_MATRA = frozenset("ाीूॄेैोौ")
    _ANUSVARA_DEV = frozenset("ंः")
    _VIRAMA = "्"
    _DEV_CONSONANTS = frozenset(
        "कखगघङचछजझञटठडढणतथदधनपफबभमयरलवशषसह"
    )

    def __init__(self) -> None:
        pass

    # ── public API ───────────────────────────────────────────────────────────

    def analyze(self, text: str) -> MeterResult:
        """Analyze prosody of Sanskrit text → MeterResult."""
        # Detect script
        if any(c in self._DEV_CONSONANTS or c in self._SHORT_V_DEV or c in self._LONG_V_DEV for c in text):
            pattern = self._quantize_devanagari(text)
        else:
            pattern = self._quantize_iast(text)
        return MeterResult(text, pattern)

    def prastara(self, n: int) -> List[str]:
        """Generate all 2^n binary meter patterns of length *n*."""
        return [bin(i)[2:].zfill(n) for i in range(2 ** n)]

    def nashtam(self, index: int, length: int) -> str:
        """Naṣṭam: given an index, return the meter pattern (index → pattern)."""
        return bin(index)[2:].zfill(length)

    def uddishtam(self, pattern: str) -> int:
        """Uddiṣṭam: given a pattern, return its index (pattern → index)."""
        return int(pattern, 2)

    # ── Devanāgarī quantizer ─────────────────────────────────────────────────

    def _quantize_devanagari(self, text: str) -> str:
        clean = text.replace(" ", "").replace("।", "").replace("॥", "").replace("\n", "")
        chars = list(clean)
        bits: List[str] = []
        i = 0
        n = len(chars)

        while i < n:
            ch = chars[i]

            # Independent vowel
            if ch in self._SHORT_V_DEV or ch in self._LONG_V_DEV:
                weight = "1" if ch in self._LONG_V_DEV else "0"
                # Check for anusvāra / visarga after
                if i + 1 < n and chars[i + 1] in self._ANUSVARA_DEV:
                    weight = "1"
                    i += 1
                # Saṃyoga: short + 2+ consonants → guru
                if weight == "0":
                    weight = self._check_samyoga(chars, i, n)
                bits.append(weight)
                i += 1
                continue

            # Consonant + mātrā
            if ch in self._DEV_CONSONANTS:
                # Skip consonant clusters (virāma-joined)
                while i + 1 < n and chars[i + 1] == self._VIRAMA:
                    i += 2  # skip virāma + next consonant
                    if i >= n:
                        break
                i += 1
                if i >= n:
                    break
                nxt = chars[i]
                if nxt in self._SHORT_MATRA:
                    weight = "0"
                    if i + 1 < n and chars[i + 1] in self._ANUSVARA_DEV:
                        weight = "1"
                        i += 1
                    if weight == "0":
                        weight = self._check_samyoga(chars, i, n)
                    bits.append(weight)
                    i += 1
                elif nxt in self._LONG_MATRA:
                    bits.append("1")
                    i += 1
                elif nxt in self._ANUSVARA_DEV:
                    bits.append("1")
                    i += 1
                elif nxt == self._VIRAMA:
                    # Consonant with halant — no vowel — skip
                    i += 1
                else:
                    # Inherent 'a' (short)
                    weight = self._check_samyoga(chars, i - 1, n)
                    bits.append(weight)
                continue

            # mātrā without preceding consonant (shouldn't happen normally)
            if ch in self._SHORT_MATRA:
                bits.append("0")
                i += 1
            elif ch in self._LONG_MATRA:
                bits.append("1")
                i += 1
            else:
                i += 1  # skip unknown

        return "".join(bits)

    def _check_samyoga(self, chars: list, pos: int, n: int) -> str:
        """Check if a short vowel at *pos* is made guru by following conjunct."""
        consonants = 0
        j = pos + 1
        while j < n:
            c = chars[j]
            if c == self._VIRAMA:
                j += 1
                continue
            if c in self._DEV_CONSONANTS:
                consonants += 1
                j += 1
            else:
                break
        return "1" if consonants >= 2 else "0"

    # ── IAST quantizer ───────────────────────────────────────────────────────

    def _quantize_iast(self, text: str) -> str:
        clean = text.replace(" ", "").replace("|", "").replace("\n", "")
        bits: List[str] = []
        i = 0
        n = len(clean)

        while i < n:
            ch = clean[i]
            is_short = ch in self._SHORT_VOWELS_IAST
            is_long = ch in self._LONG_VOWELS_IAST

            if is_short or is_long:
                weight = "1" if is_long else "0"

                # Anusvāra / visarga → guru
                if i + 1 < n and clean[i + 1] in self._ANUSVARA_VISARGA:
                    weight = "1"

                # Saṃyoga: short vowel + 2+ consonants → guru
                if weight == "0":
                    cons = 0
                    j = i + 1
                    while j < n:
                        if clean[j] in self._ANUSVARA_VISARGA:
                            weight = "1"
                            break
                        if clean[j] not in self._SHORT_VOWELS_IAST and clean[j] not in self._LONG_VOWELS_IAST:
                            cons += 1
                            j += 1
                        else:
                            break
                    if cons > 1:
                        weight = "1"

                bits.append(weight)

            i += 1

        return "".join(bits)



# Auto-generated by scripts/scaffold_roots.py for Gana 3
from . import registry


@registry.register("3.1", root="हु", meaning="दानादनयोः", gana="Juhotyadi")
def root_3_1():
    """
    3.1 हु दानादनयोः 
    """
    return "हु"


@registry.register("3.2", root="ञिभी", meaning="भये", gana="Juhotyadi")
def root_3_2():
    """
    3.2 ञिभी भये 
    """
    return "ञिभी"


@registry.register("3.3", root="ह्री", meaning="लज्जायाम्", gana="Juhotyadi")
def root_3_3():
    """
    3.3 ह्री लज्जायाम् 
    """
    return "ह्री"


@registry.register("3.4", root="पृई", meaning="पालनपूरणयोः", gana="Juhotyadi")
def root_3_4():
    """
    3.4 पृई पालनपूरणयोः 
    """
    return "पृई"


@registry.register("3.5", root="पृ", meaning="इत्येके ह्रस्वान्तोऽयमित्येके", gana="Juhotyadi")
def root_3_5():
    """
    3.5 पृ इत्येके ह्रस्वान्तोऽयमित्येके 
    """
    return "पृ"


@registry.register("3.6", root="डुभृञ्", meaning="धारणपोषणयोः", gana="Juhotyadi")
def root_3_6():
    """
    3.6 डुभृञ् धारणपोषणयोः 
    """
    return "डुभृञ्"


@registry.register("3.7", root="माङ्", meaning="माने शब्दे च", gana="Juhotyadi")
def root_3_7():
    """
    3.7 माङ् माने शब्दे च 
    """
    return "माङ्"


@registry.register("3.8", root="ओहाङ्", meaning="गतौ", gana="Juhotyadi")
def root_3_8():
    """
    3.8 ओहाङ् गतौ 
    """
    return "ओहाङ्"


@registry.register("3.9", root="ओहाक्", meaning="त्यागे", gana="Juhotyadi")
def root_3_9():
    """
    3.9 ओहाक् त्यागे 
    """
    return "ओहाक्"


@registry.register("3.10", root="डुदाञ्", meaning="दाने", gana="Juhotyadi")
def root_3_10():
    """
    3.10 डुदाञ् दाने 
    """
    return "डुदाञ्"


@registry.register("3.11", root="डुधाञ्", meaning="धारणपोषणयोः", gana="Juhotyadi")
def root_3_11():
    """
    3.11 डुधाञ् धारणपोषणयोः 
    """
    return "डुधाञ्"


@registry.register("3.12", root="णिजिर्", meaning="शौचपोषणयोः", gana="Juhotyadi")
def root_3_12():
    """
    3.12 णिजिर् शौचपोषणयोः 
    """
    return "णिजिर्"


@registry.register("3.13", root="विजिर्", meaning="पृथग्भावे", gana="Juhotyadi")
def root_3_13():
    """
    3.13 विजिर् पृथग्भावे 
    """
    return "विजिर्"


@registry.register("3.14", root="विषॢ", meaning="व्याप्तौ", gana="Juhotyadi")
def root_3_14():
    """
    3.14 विषॢ व्याप्तौ 
    """
    return "विषॢ"


@registry.register("3.15", root="घृ", meaning="क्षरणदीप्त्योः", gana="Juhotyadi")
def root_3_15():
    """
    3.15 घृ क्षरणदीप्त्योः 
    """
    return "घृ"


@registry.register("3.16", root="हृ", meaning="प्रसह्यकरणे", gana="Juhotyadi")
def root_3_16():
    """
    3.16 हृ प्रसह्यकरणे 
    """
    return "हृ"


@registry.register("3.18", root="सृ", meaning="गतौ", gana="Juhotyadi")
def root_3_18():
    """
    3.18 सृ गतौ 
    """
    return "सृ"


@registry.register("3.19", root="भस", meaning="भर्त्सनदीप्त्योः", gana="Juhotyadi")
def root_3_19():
    """
    3.19 भस भर्त्सनदीप्त्योः 
    """
    return "भस"


@registry.register("3.20", root="कि", meaning="ज्ञाने", gana="Juhotyadi")
def root_3_20():
    """
    3.20 कि ज्ञाने 
    """
    return "कि"


@registry.register("3.21", root="कित", meaning="च", gana="Juhotyadi")
def root_3_21():
    """
    3.21 कित च
    """
    return "कित"


@registry.register("3.22", root="तुर", meaning="त्वरणे", gana="Juhotyadi")
def root_3_22():
    """
    3.22 तुर त्वरणे 
    """
    return "तुर"


@registry.register("3.23", root="धिष", meaning="शब्दे", gana="Juhotyadi")
def root_3_23():
    """
    3.23 धिष शब्दे 
    """
    return "धिष"


@registry.register("3.24", root="धन", meaning="धान्ये", gana="Juhotyadi")
def root_3_24():
    """
    3.24 धन धान्ये 
    """
    return "धन"


@registry.register("3.25", root="जन", meaning="जनने", gana="Juhotyadi")
def root_3_25():
    """
    3.25 जन जनने 
    """
    return "जन"


@registry.register("3.26", root="गा", meaning="स्तुतौ", gana="Juhotyadi")
def root_3_26():
    """
    3.26 गा स्तुतौ 
    """
    return "गा"



# Auto-generated by scripts/scaffold_rules.py
from . import registry


@registry.register("1.1.1", text="वृद्धिरादैच् ।")
def rule_1_1_1(ctx=None):
    """
    1.1.1: वृद्धिरादैच् ।
    """
    pass


@registry.register("1.1.2", text="अदेङ् गुणः ।")
def rule_1_1_2(ctx=None):
    """
    1.1.2: अदेङ् गुणः ।
    """
    pass


@registry.register("1.1.3", text="इको गुणवृद्धी ।")
def rule_1_1_3(ctx=None):
    """
    1.1.3: इको गुणवृद्धी ।
    """
    pass


@registry.register("1.1.4", text="न धातुलोप आर्धधातुके ।")
def rule_1_1_4(ctx=None):
    """
    1.1.4: न धातुलोप आर्धधातुके ।
    """
    pass


@registry.register("1.1.5", text="क्ङिति च ।")
def rule_1_1_5(ctx=None):
    """
    1.1.5: क्ङिति च ।
    """
    pass


@registry.register("1.1.6", text="दीधीवेवीटाम् ।")
def rule_1_1_6(ctx=None):
    """
    1.1.6: दीधीवेवीटाम् ।
    """
    pass


@registry.register("1.1.7", text="हलोऽनन्तराः संयोगः ।")
def rule_1_1_7(ctx=None):
    """
    1.1.7: हलोऽनन्तराः संयोगः ।
    """
    pass


@registry.register("1.1.8", text="मुखनासिकावचनोऽनुनासिकः ।")
def rule_1_1_8(ctx=None):
    """
    1.1.8: मुखनासिकावचनोऽनुनासिकः ।
    """
    pass


@registry.register("1.1.9", text="तुल्यास्यप्रयत्नं सवर्णम् ।")
def rule_1_1_9(ctx=None):
    """
    1.1.9: तुल्यास्यप्रयत्नं सवर्णम् ।
    """
    pass


@registry.register("1.1.10", text="नाज्झलौ ।")
def rule_1_1_10(ctx=None):
    """
    1.1.10: नाज्झलौ ।
    """
    pass


@registry.register("1.1.11", text="ईदूदेद्विवचनं प्रगृह्यम् ।")
def rule_1_1_11(ctx=None):
    """
    1.1.11: ईदूदेद्विवचनं प्रगृह्यम् ।
    """
    pass


@registry.register("1.1.12", text="अदसो मात् ।")
def rule_1_1_12(ctx=None):
    """
    1.1.12: अदसो मात् ।
    """
    pass


@registry.register("1.1.13", text="शे ।")
def rule_1_1_13(ctx=None):
    """
    1.1.13: शे ।
    """
    pass


@registry.register("1.1.14", text="निपात एकाजनाङ् ।")
def rule_1_1_14(ctx=None):
    """
    1.1.14: निपात एकाजनाङ् ।
    """
    pass


@registry.register("1.1.15", text="ओत् ।")
def rule_1_1_15(ctx=None):
    """
    1.1.15: ओत् ।
    """
    pass


@registry.register("1.1.16", text="सम्बुद्धौ शाकल्यस्येतावनार्षे ।")
def rule_1_1_16(ctx=None):
    """
    1.1.16: सम्बुद्धौ शाकल्यस्येतावनार्षे ।
    """
    pass


@registry.register("1.1.17", text="उञः ।")
def rule_1_1_17(ctx=None):
    """
    1.1.17: उञः ।
    """
    pass


@registry.register("1.1.18", text="ॐ ।")
def rule_1_1_18(ctx=None):
    """
    1.1.18: ॐ ।
    """
    pass


@registry.register("1.1.19", text="ईदूतौ च सप्तम्यर्थे ।")
def rule_1_1_19(ctx=None):
    """
    1.1.19: ईदूतौ च सप्तम्यर्थे ।
    """
    pass


@registry.register("1.1.20", text="दाधा घ्वदाप् ।")
def rule_1_1_20(ctx=None):
    """
    1.1.20: दाधा घ्वदाप् ।
    """
    pass


@registry.register("1.1.21", text="आद्यन्तवदेकस्मिन् ।")
def rule_1_1_21(ctx=None):
    """
    1.1.21: आद्यन्तवदेकस्मिन् ।
    """
    pass


@registry.register("1.1.22", text="तरप्तमपौ घः ।")
def rule_1_1_22(ctx=None):
    """
    1.1.22: तरप्तमपौ घः ।
    """
    pass


@registry.register("1.1.23", text="बहुगणवतुडति संख्या ।")
def rule_1_1_23(ctx=None):
    """
    1.1.23: बहुगणवतुडति संख्या ।
    """
    pass


@registry.register("1.1.24", text="ष्णान्ता षट् ।")
def rule_1_1_24(ctx=None):
    """
    1.1.24: ष्णान्ता षट् ।
    """
    pass


@registry.register("1.1.25", text="डति च ।")
def rule_1_1_25(ctx=None):
    """
    1.1.25: डति च ।
    """
    pass


@registry.register("1.1.26", text="क्तक्तवतू निष्ठा ।")
def rule_1_1_26(ctx=None):
    """
    1.1.26: क्तक्तवतू निष्ठा ।
    """
    pass


@registry.register("1.1.27", text="सर्वादीनि सर्वनामानि ।")
def rule_1_1_27(ctx=None):
    """
    1.1.27: सर्वादीनि सर्वनामानि ।
    """
    pass


@registry.register("1.1.28", text="विभाषा दिक्समासे बहुव्रीहौ ।")
def rule_1_1_28(ctx=None):
    """
    1.1.28: विभाषा दिक्समासे बहुव्रीहौ ।
    """
    pass


@registry.register("1.1.29", text="न बहुव्रीहौ ।")
def rule_1_1_29(ctx=None):
    """
    1.1.29: न बहुव्रीहौ ।
    """
    pass


@registry.register("1.1.30", text="तृतीयासमासे ।")
def rule_1_1_30(ctx=None):
    """
    1.1.30: तृतीयासमासे ।
    """
    pass


@registry.register("1.1.31", text="द्वन्द्वे च ।")
def rule_1_1_31(ctx=None):
    """
    1.1.31: द्वन्द्वे च ।
    """
    pass


@registry.register("1.1.32", text="विभाषा जसि ।")
def rule_1_1_32(ctx=None):
    """
    1.1.32: विभाषा जसि ।
    """
    pass


@registry.register("1.1.33", text="प्रथमचरमतयाल्पार्धकतिपयनेमाश्च ।")
def rule_1_1_33(ctx=None):
    """
    1.1.33: प्रथमचरमतयाल्पार्धकतिपयनेमाश्च ।
    """
    pass


@registry.register("1.1.34", text="पूर्वपरावरदक्षिणोत्तरापराधराणि व्यवस्थायामसंज्ञायाम् ।")
def rule_1_1_34(ctx=None):
    """
    1.1.34: पूर्वपरावरदक्षिणोत्तरापराधराणि व्यवस्थायामसंज्ञायाम् ।
    """
    pass


@registry.register("1.1.35", text="स्वमज्ञातिधनाख्यायाम् ।")
def rule_1_1_35(ctx=None):
    """
    1.1.35: स्वमज्ञातिधनाख्यायाम् ।
    """
    pass


@registry.register("1.1.36", text="अन्तरं बहिर्योगोपसंव्यानयोः ।")
def rule_1_1_36(ctx=None):
    """
    1.1.36: अन्तरं बहिर्योगोपसंव्यानयोः ।
    """
    pass


@registry.register("1.1.37", text="स्वरादिनिपातमव्ययम् ।")
def rule_1_1_37(ctx=None):
    """
    1.1.37: स्वरादिनिपातमव्ययम् ।
    """
    pass


@registry.register("1.1.38", text="तद्धितश्चासर्वविभक्तिः ।")
def rule_1_1_38(ctx=None):
    """
    1.1.38: तद्धितश्चासर्वविभक्तिः ।
    """
    pass


@registry.register("1.1.39", text="कृन्मेजन्तः ।")
def rule_1_1_39(ctx=None):
    """
    1.1.39: कृन्मेजन्तः ।
    """
    pass


@registry.register("1.1.40", text="क्त्वातोसुन्कसुनः ।")
def rule_1_1_40(ctx=None):
    """
    1.1.40: क्त्वातोसुन्कसुनः ।
    """
    pass


@registry.register("1.1.41", text="अव्ययीभावश्च ।")
def rule_1_1_41(ctx=None):
    """
    1.1.41: अव्ययीभावश्च ।
    """
    pass


@registry.register("1.1.42", text="शि सर्वनामस्थानम् ।")
def rule_1_1_42(ctx=None):
    """
    1.1.42: शि सर्वनामस्थानम् ।
    """
    pass


@registry.register("1.1.43", text="सुडनपुंसकस्य ।")
def rule_1_1_43(ctx=None):
    """
    1.1.43: सुडनपुंसकस्य ।
    """
    pass


@registry.register("1.1.44", text="न वेति विभाषा ।")
def rule_1_1_44(ctx=None):
    """
    1.1.44: न वेति विभाषा ।
    """
    pass


@registry.register("1.1.45", text="इग्यणः सम्प्रसारणम् ।")
def rule_1_1_45(ctx=None):
    """
    1.1.45: इग्यणः सम्प्रसारणम् ।
    """
    pass


@registry.register("1.1.46", text="आद्यन्तौ टकितौ ।")
def rule_1_1_46(ctx=None):
    """
    1.1.46: आद्यन्तौ टकितौ ।
    """
    pass


@registry.register("1.1.47", text="मिदचोऽन्त्यात्परः ।")
def rule_1_1_47(ctx=None):
    """
    1.1.47: मिदचोऽन्त्यात्परः ।
    """
    pass


@registry.register("1.1.48", text="एच इग्घ्रस्वादेशे ।")
def rule_1_1_48(ctx=None):
    """
    1.1.48: एच इग्घ्रस्वादेशे ।
    """
    pass


@registry.register("1.1.49", text="षष्ठी स्थानेयोगा ।")
def rule_1_1_49(ctx=None):
    """
    1.1.49: षष्ठी स्थानेयोगा ।
    """
    pass


@registry.register("1.1.50", text="स्थानेऽन्तरतमः ।")
def rule_1_1_50(ctx=None):
    """
    1.1.50: स्थानेऽन्तरतमः ।
    """
    pass


@registry.register("1.1.51", text="उरण् रपरः ।")
def rule_1_1_51(ctx=None):
    """
    1.1.51: उरण् रपरः ।
    """
    pass


@registry.register("1.1.52", text="अलोऽन्त्यस्य ।")
def rule_1_1_52(ctx=None):
    """
    1.1.52: अलोऽन्त्यस्य ।
    """
    pass


@registry.register("1.1.53", text="ङिच्च ।")
def rule_1_1_53(ctx=None):
    """
    1.1.53: ङिच्च ।
    """
    pass


@registry.register("1.1.54", text="आदेः परस्य ।")
def rule_1_1_54(ctx=None):
    """
    1.1.54: आदेः परस्य ।
    """
    pass


@registry.register("1.1.55", text="अनेकाल्शित्सर्वस्य ।")
def rule_1_1_55(ctx=None):
    """
    1.1.55: अनेकाल्शित्सर्वस्य ।
    """
    pass


@registry.register("1.1.56", text="स्थानिवदादेशोऽनल्विधौ ।")
def rule_1_1_56(ctx=None):
    """
    1.1.56: स्थानिवदादेशोऽनल्विधौ ।
    """
    pass


@registry.register("1.1.57", text="अचः परस्मिन् पूर्वविधौ ।")
def rule_1_1_57(ctx=None):
    """
    1.1.57: अचः परस्मिन् पूर्वविधौ ।
    """
    pass


@registry.register("1.1.58", text="न पदान्तद्विर्वचनवरेयलोपस्वरसवर्णानुस्वारदीर्घजश्चर्विधिषु ।")
def rule_1_1_58(ctx=None):
    """
    1.1.58: न पदान्तद्विर्वचनवरेयलोपस्वरसवर्णानुस्वारदीर्घजश्चर्विधिषु ।
    """
    pass


@registry.register("1.1.59", text="द्विर्वचनेऽचि ।")
def rule_1_1_59(ctx=None):
    """
    1.1.59: द्विर्वचनेऽचि ।
    """
    pass


@registry.register("1.1.60", text="अदर्शनं लोपः ।")
def rule_1_1_60(ctx=None):
    """
    1.1.60: अदर्शनं लोपः ।
    """
    pass


@registry.register("1.1.61", text="प्रत्ययस्य लुक्लुलुपः ।")
def rule_1_1_61(ctx=None):
    """
    1.1.61: प्रत्ययस्य लुक्लुलुपः ।
    """
    pass


@registry.register("1.1.62", text="प्रत्ययलोपे प्रत्ययलक्षणम् ।")
def rule_1_1_62(ctx=None):
    """
    1.1.62: प्रत्ययलोपे प्रत्ययलक्षणम् ।
    """
    pass


@registry.register("1.1.63", text="न लुमताऽङ्गस्य ।")
def rule_1_1_63(ctx=None):
    """
    1.1.63: न लुमताऽङ्गस्य ।
    """
    pass


@registry.register("1.1.64", text="अचोऽन्त्यादि टि ।")
def rule_1_1_64(ctx=None):
    """
    1.1.64: अचोऽन्त्यादि टि ।
    """
    pass


@registry.register("1.1.65", text="अलोऽन्त्यात् पूर्व उपधा ।")
def rule_1_1_65(ctx=None):
    """
    1.1.65: अलोऽन्त्यात् पूर्व उपधा ।
    """
    pass


@registry.register("1.1.66", text="तस्मिन्निति निर्दिष्ट पूर्वस्य ।")
def rule_1_1_66(ctx=None):
    """
    1.1.66: तस्मिन्निति निर्दिष्ट पूर्वस्य ।
    """
    pass


@registry.register("1.1.67", text="तस्मादित्युत्तरस्य ।")
def rule_1_1_67(ctx=None):
    """
    1.1.67: तस्मादित्युत्तरस्य ।
    """
    pass


@registry.register("1.1.68", text="स्वं रूपं शब्दस्याशब्दसंज्ञा ।")
def rule_1_1_68(ctx=None):
    """
    1.1.68: स्वं रूपं शब्दस्याशब्दसंज्ञा ।
    """
    pass


@registry.register("1.1.69", text="अणुदित् सवर्णस्य चाप्रत्ययः ।")
def rule_1_1_69(ctx=None):
    """
    1.1.69: अणुदित् सवर्णस्य चाप्रत्ययः ।
    """
    pass


@registry.register("1.1.70", text="तपरस्तत्कालस्य ।")
def rule_1_1_70(ctx=None):
    """
    1.1.70: तपरस्तत्कालस्य ।
    """
    pass


@registry.register("1.1.71", text="आदिरन्त्येन सहेता ।")
def rule_1_1_71(ctx=None):
    """
    1.1.71: आदिरन्त्येन सहेता ।
    """
    pass


@registry.register("1.1.72", text="येन विधिस्तदन्तस्य ।")
def rule_1_1_72(ctx=None):
    """
    1.1.72: येन विधिस्तदन्तस्य ।
    """
    pass


@registry.register("1.1.73", text="वृद्धिर्यस्याचामादिस्तद् वृद्धम् ।")
def rule_1_1_73(ctx=None):
    """
    1.1.73: वृद्धिर्यस्याचामादिस्तद् वृद्धम् ।
    """
    pass


@registry.register("1.1.74", text="त्यदादीनि च ।")
def rule_1_1_74(ctx=None):
    """
    1.1.74: त्यदादीनि च ।
    """
    pass


@registry.register("1.1.75", text="एङ् प्राचां देशे ।")
def rule_1_1_75(ctx=None):
    """
    1.1.75: एङ् प्राचां देशे ।
    """
    pass


@registry.register("1.2.1", text="गाङ्कुङ्कटादिभ्योऽञ्णिन्ङ् इत् ।")
def rule_1_2_1(ctx=None):
    """
    1.2.1: गाङ्कुङ्कटादिभ्योऽञ्णिन्ङ् इत् ।
    """
    pass


@registry.register("1.2.2", text="विज इट् ।")
def rule_1_2_2(ctx=None):
    """
    1.2.2: विज इट् ।
    """
    pass


@registry.register("1.2.3", text="विभाषोर्णोः ।")
def rule_1_2_3(ctx=None):
    """
    1.2.3: विभाषोर्णोः ।
    """
    pass


@registry.register("1.2.4", text="सार्वधातुकमपित् ।")
def rule_1_2_4(ctx=None):
    """
    1.2.4: सार्वधातुकमपित् ।
    """
    pass


@registry.register("1.2.5", text="असंयोगाल्लिट् कित् ।")
def rule_1_2_5(ctx=None):
    """
    1.2.5: असंयोगाल्लिट् कित् ।
    """
    pass


@registry.register("1.2.6", text="इन्धिभवतिभ्यां च ।")
def rule_1_2_6(ctx=None):
    """
    1.2.6: इन्धिभवतिभ्यां च ।
    """
    pass


@registry.register("1.2.7", text="मृडमृदगुधकुषक्लिशवदवसः ।")
def rule_1_2_7(ctx=None):
    """
    1.2.7: मृडमृदगुधकुषक्लिशवदवसः ।
    """
    pass


@registry.register("1.2.8", text="रुदविदमुषग्रहिस्वपिप्रच्छः सँश्च ।")
def rule_1_2_8(ctx=None):
    """
    1.2.8: रुदविदमुषग्रहिस्वपिप्रच्छः सँश्च ।
    """
    pass


@registry.register("1.2.9", text="इको झल् ।")
def rule_1_2_9(ctx=None):
    """
    1.2.9: इको झल् ।
    """
    pass


@registry.register("1.2.10", text="हलन्ताच्च ।")
def rule_1_2_10(ctx=None):
    """
    1.2.10: हलन्ताच्च ।
    """
    pass


@registry.register("1.2.11", text="लिङ्खिचावात्मनेपदेषु ।")
def rule_1_2_11(ctx=None):
    """
    1.2.11: लिङ्खिचावात्मनेपदेषु ।
    """
    pass


@registry.register("1.2.12", text="उश्च ।")
def rule_1_2_12(ctx=None):
    """
    1.2.12: उश्च ।
    """
    pass


@registry.register("1.2.13", text="वा गमः ।")
def rule_1_2_13(ctx=None):
    """
    1.2.13: वा गमः ।
    """
    pass


@registry.register("1.2.14", text="हनः सिच् ।")
def rule_1_2_14(ctx=None):
    """
    1.2.14: हनः सिच् ।
    """
    pass


@registry.register("1.2.15", text="यमो गन्धने ।")
def rule_1_2_15(ctx=None):
    """
    1.2.15: यमो गन्धने ।
    """
    pass


@registry.register("1.2.16", text="विभाषोपयमने ।")
def rule_1_2_16(ctx=None):
    """
    1.2.16: विभाषोपयमने ।
    """
    pass


@registry.register("1.2.17", text="स्थाघ्वोरिच्च ।")
def rule_1_2_17(ctx=None):
    """
    1.2.17: स्थाघ्वोरिच्च ।
    """
    pass


@registry.register("1.2.18", text="न सेट् ।")
def rule_1_2_18(ctx=None):
    """
    1.2.18: न सेट् ।
    """
    pass


@registry.register("1.2.19", text="निष्ठा शीङ्खिदिमिदिक्ष्विदिधृषः ।")
def rule_1_2_19(ctx=None):
    """
    1.2.19: निष्ठा शीङ्खिदिमिदिक्ष्विदिधृषः ।
    """
    pass


@registry.register("1.2.20", text="मृषस्तितिक्षायाम् ।")
def rule_1_2_20(ctx=None):
    """
    1.2.20: मृषस्तितिक्षायाम् ।
    """
    pass


@registry.register("1.2.21", text="उदुपधाद्भावादिकर्मणोरन्यतरस्याम् ।")
def rule_1_2_21(ctx=None):
    """
    1.2.21: उदुपधाद्भावादिकर्मणोरन्यतरस्याम् ।
    """
    pass


@registry.register("1.2.22", text="पूङः च ।")
def rule_1_2_22(ctx=None):
    """
    1.2.22: पूङः च ।
    """
    pass


@registry.register("1.2.23", text="नोपधात्थफान्ताद्वा ।")
def rule_1_2_23(ctx=None):
    """
    1.2.23: नोपधात्थफान्ताद्वा ।
    """
    pass


@registry.register("1.2.24", text="वञ्चिलुच्यृतश्च ।")
def rule_1_2_24(ctx=None):
    """
    1.2.24: वञ्चिलुच्यृतश्च ।
    """
    pass


@registry.register("1.2.25", text="तृषिमृषिकृशः काश्यपस्य ।")
def rule_1_2_25(ctx=None):
    """
    1.2.25: तृषिमृषिकृशः काश्यपस्य ।
    """
    pass


@registry.register("1.2.26", text="रलो व्युपधाद्धलादेः संश्च ।")
def rule_1_2_26(ctx=None):
    """
    1.2.26: रलो व्युपधाद्धलादेः संश्च ।
    """
    pass


@registry.register("1.2.27", text="ऊकालोऽज्यस्वदीर्घप्लुतः ।")
def rule_1_2_27(ctx=None):
    """
    1.2.27: ऊकालोऽज्यस्वदीर्घप्लुतः ।
    """
    pass


@registry.register("1.2.28", text="अचश्च ।")
def rule_1_2_28(ctx=None):
    """
    1.2.28: अचश्च ।
    """
    pass


@registry.register("1.2.29", text="उच्चैरुदात्तः ।")
def rule_1_2_29(ctx=None):
    """
    1.2.29: उच्चैरुदात्तः ।
    """
    pass


@registry.register("1.2.30", text="नीचैरनुदात्तः ।")
def rule_1_2_30(ctx=None):
    """
    1.2.30: नीचैरनुदात्तः ।
    """
    pass


@registry.register("1.2.31", text="समाहारः स्वरितः ।")
def rule_1_2_31(ctx=None):
    """
    1.2.31: समाहारः स्वरितः ।
    """
    pass


@registry.register("1.2.32", text="तस्यादित उदात्तमर्धह्रस्वम् ।")
def rule_1_2_32(ctx=None):
    """
    1.2.32: तस्यादित उदात्तमर्धह्रस्वम् ।
    """
    pass


@registry.register("1.2.33", text="एकश्रुति दूरात् सम्बुद्धौ ।")
def rule_1_2_33(ctx=None):
    """
    1.2.33: एकश्रुति दूरात् सम्बुद्धौ ।
    """
    pass


@registry.register("1.2.34", text="यज्ञकर्मण्यजपन्यूङ्खसामसु ।")
def rule_1_2_34(ctx=None):
    """
    1.2.34: यज्ञकर्मण्यजपन्यूङ्खसामसु ।
    """
    pass


@registry.register("1.2.35", text="उच्चैस्तरां वा वषङ्कारः ।")
def rule_1_2_35(ctx=None):
    """
    1.2.35: उच्चैस्तरां वा वषङ्कारः ।
    """
    pass


@registry.register("1.2.36", text="विभाषा छन्दसि ।")
def rule_1_2_36(ctx=None):
    """
    1.2.36: विभाषा छन्दसि ।
    """
    pass


@registry.register("1.2.37", text="न सुब्रह्मण्यायां स्वरितस्य तूदात्तः ।")
def rule_1_2_37(ctx=None):
    """
    1.2.37: न सुब्रह्मण्यायां स्वरितस्य तूदात्तः ।
    """
    pass


@registry.register("1.2.38", text="देवब्रह्मणोरनुदात्तः ।")
def rule_1_2_38(ctx=None):
    """
    1.2.38: देवब्रह्मणोरनुदात्तः ।
    """
    pass


@registry.register("1.2.39", text="स्वरितात् संहितायामनुदात्तानाम् ।")
def rule_1_2_39(ctx=None):
    """
    1.2.39: स्वरितात् संहितायामनुदात्तानाम् ।
    """
    pass


@registry.register("1.2.40", text="उदात्तस्वरितपरस्य सन्नतरः ।")
def rule_1_2_40(ctx=None):
    """
    1.2.40: उदात्तस्वरितपरस्य सन्नतरः ।
    """
    pass


@registry.register("1.2.41", text="अपृक्त एकाल् प्रत्ययः ।")
def rule_1_2_41(ctx=None):
    """
    1.2.41: अपृक्त एकाल् प्रत्ययः ।
    """
    pass


@registry.register("1.2.42", text="तत्पुरुषः समानाधिकरणः कर्मधारयः ।")
def rule_1_2_42(ctx=None):
    """
    1.2.42: तत्पुरुषः समानाधिकरणः कर्मधारयः ।
    """
    pass


@registry.register("1.2.43", text="प्रथमानिर्दिष्टं समास उपसर्जनम् ।")
def rule_1_2_43(ctx=None):
    """
    1.2.43: प्रथमानिर्दिष्टं समास उपसर्जनम् ।
    """
    pass


@registry.register("1.2.44", text="एकविभक्ति चापूर्वनिपाते ।")
def rule_1_2_44(ctx=None):
    """
    1.2.44: एकविभक्ति चापूर्वनिपाते ।
    """
    pass


@registry.register("1.2.45", text="अर्थवदधातुरप्रत्ययः प्रातिपदिकम् ।")
def rule_1_2_45(ctx=None):
    """
    1.2.45: अर्थवदधातुरप्रत्ययः प्रातिपदिकम् ।
    """
    pass


@registry.register("1.2.46", text="कृत्तद्धितसमासाश्च ।")
def rule_1_2_46(ctx=None):
    """
    1.2.46: कृत्तद्धितसमासाश्च ।
    """
    pass


@registry.register("1.2.47", text="ह्रस्वो नपुंसके प्रातिपदिकस्य ।")
def rule_1_2_47(ctx=None):
    """
    1.2.47: ह्रस्वो नपुंसके प्रातिपदिकस्य ।
    """
    pass


@registry.register("1.2.48", text="गोस्त्रियोरुपसर्जनस्य ।")
def rule_1_2_48(ctx=None):
    """
    1.2.48: गोस्त्रियोरुपसर्जनस्य ।
    """
    pass


@registry.register("1.2.49", text="लुक् तद्धितलुकि ।")
def rule_1_2_49(ctx=None):
    """
    1.2.49: लुक् तद्धितलुकि ।
    """
    pass


@registry.register("1.2.50", text="इद्गोण्याः ।")
def rule_1_2_50(ctx=None):
    """
    1.2.50: इद्गोण्याः ।
    """
    pass


@registry.register("1.2.51", text="लुपि युक्तवद्व्यक्तिवचने ।")
def rule_1_2_51(ctx=None):
    """
    1.2.51: लुपि युक्तवद्व्यक्तिवचने ।
    """
    pass


@registry.register("1.2.52", text="विशेषणानां चाजातेः ।")
def rule_1_2_52(ctx=None):
    """
    1.2.52: विशेषणानां चाजातेः ।
    """
    pass


@registry.register("1.2.53", text="तदशिष्यं संज्ञाप्रमाणत्वात् ।")
def rule_1_2_53(ctx=None):
    """
    1.2.53: तदशिष्यं संज्ञाप्रमाणत्वात् ।
    """
    pass


@registry.register("1.2.54", text="लुब्योगाप्रख्यानात् ।")
def rule_1_2_54(ctx=None):
    """
    1.2.54: लुब्योगाप्रख्यानात् ।
    """
    pass


@registry.register("1.2.55", text="योगप्रमाणे च तदभावेऽदर्शनं स्यात् ।")
def rule_1_2_55(ctx=None):
    """
    1.2.55: योगप्रमाणे च तदभावेऽदर्शनं स्यात् ।
    """
    pass


@registry.register("1.2.56", text="प्रधानप्रत्ययार्थवचनमर्थस्यान्यप्रमाणत्वात् ।")
def rule_1_2_56(ctx=None):
    """
    1.2.56: प्रधानप्रत्ययार्थवचनमर्थस्यान्यप्रमाणत्वात् ।
    """
    pass


@registry.register("1.2.57", text="कालोपसर्जने च तुल्यम् ।")
def rule_1_2_57(ctx=None):
    """
    1.2.57: कालोपसर्जने च तुल्यम् ।
    """
    pass


@registry.register("1.2.58", text="जात्याख्यायामेकस्मिन् बहुवचनमन्यतरस्याम् ।")
def rule_1_2_58(ctx=None):
    """
    1.2.58: जात्याख्यायामेकस्मिन् बहुवचनमन्यतरस्याम् ।
    """
    pass


@registry.register("1.2.59", text="अस्मदो द्वयोश्च ।")
def rule_1_2_59(ctx=None):
    """
    1.2.59: अस्मदो द्वयोश्च ।
    """
    pass


@registry.register("1.2.60", text="फल्गुनीप्रोष्ठपदानां च नक्षत्रे ।")
def rule_1_2_60(ctx=None):
    """
    1.2.60: फल्गुनीप्रोष्ठपदानां च नक्षत्रे ।
    """
    pass


@registry.register("1.2.61", text="छन्दसि पुनर्वस्वोरेकवचनम् ।")
def rule_1_2_61(ctx=None):
    """
    1.2.61: छन्दसि पुनर्वस्वोरेकवचनम् ।
    """
    pass


@registry.register("1.2.62", text="विशाखयोश्च ।")
def rule_1_2_62(ctx=None):
    """
    1.2.62: विशाखयोश्च ।
    """
    pass


@registry.register("1.2.63", text="तिष्यपुनर्वस्वोर्नक्षत्रद्वंद्वे बहुवचनस्य द्विवचनं नित्यम् ।")
def rule_1_2_63(ctx=None):
    """
    1.2.63: तिष्यपुनर्वस्वोर्नक्षत्रद्वंद्वे बहुवचनस्य द्विवचनं नित्यम् ।
    """
    pass


@registry.register("1.2.64", text="सरूपाणामेकशेष एकविभक्तौ ।")
def rule_1_2_64(ctx=None):
    """
    1.2.64: सरूपाणामेकशेष एकविभक्तौ ।
    """
    pass


@registry.register("1.2.65", text="वृद्धो यूना तल्लक्षणश्चेदेव विशेषः ।")
def rule_1_2_65(ctx=None):
    """
    1.2.65: वृद्धो यूना तल्लक्षणश्चेदेव विशेषः ।
    """
    pass


@registry.register("1.2.66", text="स्त्री पुंवच्च ।")
def rule_1_2_66(ctx=None):
    """
    1.2.66: स्त्री पुंवच्च ।
    """
    pass


@registry.register("1.2.67", text="पुमान् स्त्रिया ।")
def rule_1_2_67(ctx=None):
    """
    1.2.67: पुमान् स्त्रिया ।
    """
    pass


@registry.register("1.2.68", text="भ्रातृपुत्रौ स्वसृदुहितृभ्याम् ।")
def rule_1_2_68(ctx=None):
    """
    1.2.68: भ्रातृपुत्रौ स्वसृदुहितृभ्याम् ।
    """
    pass


@registry.register("1.2.69", text="नपुंसकमनपुंसकेनैकवच्चास्यान्यतरस्याम् ।")
def rule_1_2_69(ctx=None):
    """
    1.2.69: नपुंसकमनपुंसकेनैकवच्चास्यान्यतरस्याम् ।
    """
    pass


@registry.register("1.2.70", text="पिता मात्रा ।")
def rule_1_2_70(ctx=None):
    """
    1.2.70: पिता मात्रा ।
    """
    pass


@registry.register("1.2.71", text="श्वशुरः श्वश्वा ।")
def rule_1_2_71(ctx=None):
    """
    1.2.71: श्वशुरः श्वश्वा ।
    """
    pass


@registry.register("1.2.72", text="त्यदादीनि सर्वैर्नित्यम् ।")
def rule_1_2_72(ctx=None):
    """
    1.2.72: त्यदादीनि सर्वैर्नित्यम् ।
    """
    pass


@registry.register("1.2.73", text="ग्राम्यपशुसंघेषु अतरुणेषु स्त्री ।")
def rule_1_2_73(ctx=None):
    """
    1.2.73: ग्राम्यपशुसंघेषु अतरुणेषु स्त्री ।
    """
    pass


@registry.register("1.3.1", text="भूवादयो धातवः ।")
def rule_1_3_1(ctx=None):
    """
    1.3.1: भूवादयो धातवः ।
    """
    pass


@registry.register("1.3.2", text="उपदेशेऽजनुनासिक इत् ।")
def rule_1_3_2(ctx=None):
    """
    1.3.2: उपदेशेऽजनुनासिक इत् ।
    """
    pass


@registry.register("1.3.3", text="हलन्त्यम् ।")
def rule_1_3_3(ctx=None):
    """
    1.3.3: हलन्त्यम् ।
    """
    pass


@registry.register("1.3.4", text="न विभक्तौ तुस्माः ।")
def rule_1_3_4(ctx=None):
    """
    1.3.4: न विभक्तौ तुस्माः ।
    """
    pass


@registry.register("1.3.5", text="आदिर्जिटुडवः ।")
def rule_1_3_5(ctx=None):
    """
    1.3.5: आदिर्जिटुडवः ।
    """
    pass


@registry.register("1.3.6", text="षः प्रत्ययस्य ।")
def rule_1_3_6(ctx=None):
    """
    1.3.6: षः प्रत्ययस्य ।
    """
    pass


@registry.register("1.3.7", text="चुटू ।")
def rule_1_3_7(ctx=None):
    """
    1.3.7: चुटू ।
    """
    pass


@registry.register("1.3.8", text="लशक्वतद्धिते ।")
def rule_1_3_8(ctx=None):
    """
    1.3.8: लशक्वतद्धिते ।
    """
    pass


@registry.register("1.3.9", text="तस्य लोपः ।")
def rule_1_3_9(ctx=None):
    """
    1.3.9: तस्य लोपः ।
    """
    pass


@registry.register("1.3.10", text="यथासंख्यम् अनुदेशः समानाम् ।")
def rule_1_3_10(ctx=None):
    """
    1.3.10: यथासंख्यम् अनुदेशः समानाम् ।
    """
    pass


@registry.register("1.3.11", text="स्वरितेनाधिकारः ।")
def rule_1_3_11(ctx=None):
    """
    1.3.11: स्वरितेनाधिकारः ।
    """
    pass


@registry.register("1.3.12", text="अनुदात्तङित आत्मनेपदम् ।")
def rule_1_3_12(ctx=None):
    """
    1.3.12: अनुदात्तङित आत्मनेपदम् ।
    """
    pass


@registry.register("1.3.13", text="भावकर्मणोः ।")
def rule_1_3_13(ctx=None):
    """
    1.3.13: भावकर्मणोः ।
    """
    pass


@registry.register("1.3.14", text="कर्तरि कर्मव्यतिहारे ।")
def rule_1_3_14(ctx=None):
    """
    1.3.14: कर्तरि कर्मव्यतिहारे ।
    """
    pass


@registry.register("1.3.15", text="न गतिहिंसार्थेभ्यः ।")
def rule_1_3_15(ctx=None):
    """
    1.3.15: न गतिहिंसार्थेभ्यः ।
    """
    pass


@registry.register("1.3.16", text="इतरेतरान्योन्योपपदाच्च ।")
def rule_1_3_16(ctx=None):
    """
    1.3.16: इतरेतरान्योन्योपपदाच्च ।
    """
    pass


@registry.register("1.3.17", text="नेर्विशः ।")
def rule_1_3_17(ctx=None):
    """
    1.3.17: नेर्विशः ।
    """
    pass


@registry.register("1.3.18", text="परिव्यवेभ्यः क्रियः ।")
def rule_1_3_18(ctx=None):
    """
    1.3.18: परिव्यवेभ्यः क्रियः ।
    """
    pass


@registry.register("1.3.19", text="विपराभ्यां जेः ।")
def rule_1_3_19(ctx=None):
    """
    1.3.19: विपराभ्यां जेः ।
    """
    pass


@registry.register("1.3.20", text="आङो दोऽनास्यविहरणे ।")
def rule_1_3_20(ctx=None):
    """
    1.3.20: आङो दोऽनास्यविहरणे ।
    """
    pass


@registry.register("1.3.21", text="क्रीडोऽनुसम्परिभ्यश्च ।")
def rule_1_3_21(ctx=None):
    """
    1.3.21: क्रीडोऽनुसम्परिभ्यश्च ।
    """
    pass


@registry.register("1.3.22", text="समवप्रविभ्यः स्थः ।")
def rule_1_3_22(ctx=None):
    """
    1.3.22: समवप्रविभ्यः स्थः ।
    """
    pass


@registry.register("1.3.23", text="प्रकाशनस्थेयाख्ययोश्च ।")
def rule_1_3_23(ctx=None):
    """
    1.3.23: प्रकाशनस्थेयाख्ययोश्च ।
    """
    pass


@registry.register("1.3.24", text="उदोऽनूर्द्धकर्मणि ।")
def rule_1_3_24(ctx=None):
    """
    1.3.24: उदोऽनूर्द्धकर्मणि ।
    """
    pass


@registry.register("1.3.25", text="उपान्मन्त्रकरणे ।")
def rule_1_3_25(ctx=None):
    """
    1.3.25: उपान्मन्त्रकरणे ।
    """
    pass


@registry.register("1.3.26", text="अकर्मकाच्च ।")
def rule_1_3_26(ctx=None):
    """
    1.3.26: अकर्मकाच्च ।
    """
    pass


@registry.register("1.3.27", text="उद्विभ्यां तपः ।")
def rule_1_3_27(ctx=None):
    """
    1.3.27: उद्विभ्यां तपः ।
    """
    pass


@registry.register("1.3.28", text="आङो यमहनः ।")
def rule_1_3_28(ctx=None):
    """
    1.3.28: आङो यमहनः ।
    """
    pass


@registry.register("1.3.29", text="समो गम्यृच्छिप्रच्छिस्वरत्यर्तिश्रुविदिभ्यः ।")
def rule_1_3_29(ctx=None):
    """
    1.3.29: समो गम्यृच्छिप्रच्छिस्वरत्यर्तिश्रुविदिभ्यः ।
    """
    pass


@registry.register("1.3.30", text="निसमुपविभ्यो ।")
def rule_1_3_30(ctx=None):
    """
    1.3.30: निसमुपविभ्यो ।
    """
    pass


@registry.register("1.3.31", text="स्पर्द्धायामाङः ।")
def rule_1_3_31(ctx=None):
    """
    1.3.31: स्पर्द्धायामाङः ।
    """
    pass


@registry.register("1.3.32", text="गन्धनावक्षेपणसेवनसाहसिक्यप्रतियत्नप्रकथनोपयोगेषु कृञः ।")
def rule_1_3_32(ctx=None):
    """
    1.3.32: गन्धनावक्षेपणसेवनसाहसिक्यप्रतियत्नप्रकथनोपयोगेषु कृञः ।
    """
    pass


@registry.register("1.3.33", text="अधेः प्रसहने ।")
def rule_1_3_33(ctx=None):
    """
    1.3.33: अधेः प्रसहने ।
    """
    pass


@registry.register("1.3.34", text="वेः शब्दकर्मणः ।")
def rule_1_3_34(ctx=None):
    """
    1.3.34: वेः शब्दकर्मणः ।
    """
    pass


@registry.register("1.3.35", text="अकर्मकाच्च ।")
def rule_1_3_35(ctx=None):
    """
    1.3.35: अकर्मकाच्च ।
    """
    pass


@registry.register("1.3.36", text="सम्माननोत्सञ्जनाचार्यकरणज्ञानभृतिविगणनव्ययेषु नियः ।")
def rule_1_3_36(ctx=None):
    """
    1.3.36: सम्माननोत्सञ्जनाचार्यकरणज्ञानभृतिविगणनव्ययेषु नियः ।
    """
    pass


@registry.register("1.3.37", text="कर्तृस्थे चाशरीरे कर्मणि ।")
def rule_1_3_37(ctx=None):
    """
    1.3.37: कर्तृस्थे चाशरीरे कर्मणि ।
    """
    pass


@registry.register("1.3.38", text="वृत्तिसर्गतायनेषु क्रमः ।")
def rule_1_3_38(ctx=None):
    """
    1.3.38: वृत्तिसर्गतायनेषु क्रमः ।
    """
    pass


@registry.register("1.3.39", text="उपपराभ्याम् ।")
def rule_1_3_39(ctx=None):
    """
    1.3.39: उपपराभ्याम् ।
    """
    pass


@registry.register("1.3.40", text="आङ उद्गमने ।")
def rule_1_3_40(ctx=None):
    """
    1.3.40: आङ उद्गमने ।
    """
    pass


@registry.register("1.3.41", text="वेः पादविहरणे ।")
def rule_1_3_41(ctx=None):
    """
    1.3.41: वेः पादविहरणे ।
    """
    pass


@registry.register("1.3.42", text="प्रोपाभ्यां समर्थाभ्याम् ।")
def rule_1_3_42(ctx=None):
    """
    1.3.42: प्रोपाभ्यां समर्थाभ्याम् ।
    """
    pass


@registry.register("1.3.43", text="अनुपसर्गाद्वा ।")
def rule_1_3_43(ctx=None):
    """
    1.3.43: अनुपसर्गाद्वा ।
    """
    pass


@registry.register("1.3.44", text="अपह्नवे ज्ञः ।")
def rule_1_3_44(ctx=None):
    """
    1.3.44: अपह्नवे ज्ञः ।
    """
    pass


@registry.register("1.3.45", text="अकर्मकाच्च ।")
def rule_1_3_45(ctx=None):
    """
    1.3.45: अकर्मकाच्च ।
    """
    pass


@registry.register("1.3.46", text="सम्प्रतिभ्यामनाध्याने ।")
def rule_1_3_46(ctx=None):
    """
    1.3.46: सम्प्रतिभ्यामनाध्याने ।
    """
    pass


@registry.register("1.3.47", text="भासनोपसम्भाषाज्ञानयत्नविमत्युपमन्त्रणेषु वदः ।")
def rule_1_3_47(ctx=None):
    """
    1.3.47: भासनोपसम्भाषाज्ञानयत्नविमत्युपमन्त्रणेषु वदः ।
    """
    pass


@registry.register("1.3.48", text="व्यक्तवाचां समुच्चारणे ।")
def rule_1_3_48(ctx=None):
    """
    1.3.48: व्यक्तवाचां समुच्चारणे ।
    """
    pass


@registry.register("1.3.49", text="अनोरकर्मकात् ।")
def rule_1_3_49(ctx=None):
    """
    1.3.49: अनोरकर्मकात् ।
    """
    pass


@registry.register("1.3.50", text="विभाषा विप्रलापे ।")
def rule_1_3_50(ctx=None):
    """
    1.3.50: विभाषा विप्रलापे ।
    """
    pass


@registry.register("1.3.51", text="अवाद्भः ।")
def rule_1_3_51(ctx=None):
    """
    1.3.51: अवाद्भः ।
    """
    pass


@registry.register("1.3.52", text="समः प्रतिज्ञाने ।")
def rule_1_3_52(ctx=None):
    """
    1.3.52: समः प्रतिज्ञाने ।
    """
    pass


@registry.register("1.3.53", text="उदश्वरः सकर्मकात् ।")
def rule_1_3_53(ctx=None):
    """
    1.3.53: उदश्वरः सकर्मकात् ।
    """
    pass


@registry.register("1.3.54", text="समस्तृतीयायुक्तात् ।")
def rule_1_3_54(ctx=None):
    """
    1.3.54: समस्तृतीयायुक्तात् ।
    """
    pass


@registry.register("1.3.55", text="दाणश्च सा चेच्चतुर्थ्यर्थे ।")
def rule_1_3_55(ctx=None):
    """
    1.3.55: दाणश्च सा चेच्चतुर्थ्यर्थे ।
    """
    pass


@registry.register("1.3.56", text="उपाद्यमः स्वकरणे ।")
def rule_1_3_56(ctx=None):
    """
    1.3.56: उपाद्यमः स्वकरणे ।
    """
    pass


@registry.register("1.3.57", text="ज्ञाश्रुस्मृदृशां सनः ।")
def rule_1_3_57(ctx=None):
    """
    1.3.57: ज्ञाश्रुस्मृदृशां सनः ।
    """
    pass


@registry.register("1.3.58", text="नानोज्ञः ।")
def rule_1_3_58(ctx=None):
    """
    1.3.58: नानोज्ञः ।
    """
    pass


@registry.register("1.3.59", text="प्रत्यायां श्रुवः ।")
def rule_1_3_59(ctx=None):
    """
    1.3.59: प्रत्यायां श्रुवः ।
    """
    pass


@registry.register("1.3.60", text="शदेः शितः ।")
def rule_1_3_60(ctx=None):
    """
    1.3.60: शदेः शितः ।
    """
    pass


@registry.register("1.3.61", text="म्रियतेर्लुङ्किङोश्च ।")
def rule_1_3_61(ctx=None):
    """
    1.3.61: म्रियतेर्लुङ्किङोश्च ।
    """
    pass


@registry.register("1.3.62", text="पूर्ववत् सनः ।")
def rule_1_3_62(ctx=None):
    """
    1.3.62: पूर्ववत् सनः ।
    """
    pass


@registry.register("1.3.63", text="आम्प्रत्ययवत् कृञोऽनुप्रयोगस्य ।")
def rule_1_3_63(ctx=None):
    """
    1.3.63: आम्प्रत्ययवत् कृञोऽनुप्रयोगस्य ।
    """
    pass


@registry.register("1.3.64", text="प्रोपाभ्यां युजेरयज्ञपात्रेषु ।")
def rule_1_3_64(ctx=None):
    """
    1.3.64: प्रोपाभ्यां युजेरयज्ञपात्रेषु ।
    """
    pass


@registry.register("1.3.65", text="समः क्ष्णुवः ।")
def rule_1_3_65(ctx=None):
    """
    1.3.65: समः क्ष्णुवः ।
    """
    pass


@registry.register("1.3.66", text="भुजोऽनवने ।")
def rule_1_3_66(ctx=None):
    """
    1.3.66: भुजोऽनवने ।
    """
    pass


@registry.register("1.3.67", text="णेरणौ यत् कर्म णौ चेत् स कर्ताऽनाध्याने ।")
def rule_1_3_67(ctx=None):
    """
    1.3.67: णेरणौ यत् कर्म णौ चेत् स कर्ताऽनाध्याने ।
    """
    pass


@registry.register("1.3.68", text="भीस्म्योर्हेतुभये ।")
def rule_1_3_68(ctx=None):
    """
    1.3.68: भीस्म्योर्हेतुभये ।
    """
    pass


@registry.register("1.3.69", text="गृधिवच्योः प्रलम्भने ।")
def rule_1_3_69(ctx=None):
    """
    1.3.69: गृधिवच्योः प्रलम्भने ।
    """
    pass


@registry.register("1.3.70", text="लियः सम्माननशालिनीकरणयोश्च ।")
def rule_1_3_70(ctx=None):
    """
    1.3.70: लियः सम्माननशालिनीकरणयोश्च ।
    """
    pass


@registry.register("1.3.71", text="मिथ्योपपदात् कृञोऽभ्यासे ।")
def rule_1_3_71(ctx=None):
    """
    1.3.71: मिथ्योपपदात् कृञोऽभ्यासे ।
    """
    pass


@registry.register("1.3.72", text="स्वरितञितः कर्त्रभिप्राये क्रियाफले ।")
def rule_1_3_72(ctx=None):
    """
    1.3.72: स्वरितञितः कर्त्रभिप्राये क्रियाफले ।
    """
    pass


@registry.register("1.3.73", text="अपाद्वदः ।")
def rule_1_3_73(ctx=None):
    """
    1.3.73: अपाद्वदः ।
    """
    pass


@registry.register("1.3.74", text="णिचश्च ।")
def rule_1_3_74(ctx=None):
    """
    1.3.74: णिचश्च ।
    """
    pass


@registry.register("1.3.75", text="समुदायो यमोऽग्रन्थे ।")
def rule_1_3_75(ctx=None):
    """
    1.3.75: समुदायो यमोऽग्रन्थे ।
    """
    pass


@registry.register("1.3.76", text="अनुपसर्गाज्ज्ञः ।")
def rule_1_3_76(ctx=None):
    """
    1.3.76: अनुपसर्गाज्ज्ञः ।
    """
    pass


@registry.register("1.3.77", text="विभाषोपपदेन प्रतीयमाने ।")
def rule_1_3_77(ctx=None):
    """
    1.3.77: विभाषोपपदेन प्रतीयमाने ।
    """
    pass


@registry.register("1.3.78", text="शेषात् कर्तरि परस्मैपदम् ।")
def rule_1_3_78(ctx=None):
    """
    1.3.78: शेषात् कर्तरि परस्मैपदम् ।
    """
    pass


@registry.register("1.3.79", text="अनुपराभ्यां कृञः ।")
def rule_1_3_79(ctx=None):
    """
    1.3.79: अनुपराभ्यां कृञः ।
    """
    pass


@registry.register("1.3.80", text="अभिप्रत्यतिभ्यः क्षिपः ।")
def rule_1_3_80(ctx=None):
    """
    1.3.80: अभिप्रत्यतिभ्यः क्षिपः ।
    """
    pass


@registry.register("1.3.81", text="प्राद्वहः ।")
def rule_1_3_81(ctx=None):
    """
    1.3.81: प्राद्वहः ।
    """
    pass


@registry.register("1.3.82", text="परेर्मुषः ।")
def rule_1_3_82(ctx=None):
    """
    1.3.82: परेर्मुषः ।
    """
    pass


@registry.register("1.3.83", text="व्याङ्गरिभ्यो रमः ।")
def rule_1_3_83(ctx=None):
    """
    1.3.83: व्याङ्गरिभ्यो रमः ।
    """
    pass


@registry.register("1.3.84", text="उपाच्च ।")
def rule_1_3_84(ctx=None):
    """
    1.3.84: उपाच्च ।
    """
    pass


@registry.register("1.3.85", text="विभाषाऽकर्मकात् ।")
def rule_1_3_85(ctx=None):
    """
    1.3.85: विभाषाऽकर्मकात् ।
    """
    pass


@registry.register("1.3.86", text="बुधयुधनशजनेङ्घद्रुस्रुभ्यो णेः ।")
def rule_1_3_86(ctx=None):
    """
    1.3.86: बुधयुधनशजनेङ्घद्रुस्रुभ्यो णेः ।
    """
    pass


@registry.register("1.3.87", text="निगरणचलनार्थेभ्यः ।")
def rule_1_3_87(ctx=None):
    """
    1.3.87: निगरणचलनार्थेभ्यः ।
    """
    pass


@registry.register("1.3.88", text="अणावकर्मकाच्चित्तवत्कर्तृकात् ।")
def rule_1_3_88(ctx=None):
    """
    1.3.88: अणावकर्मकाच्चित्तवत्कर्तृकात् ।
    """
    pass


@registry.register("1.3.89", text="न पादम्याङयमाङयसपरिमुहरुचिनृतिवदवसः ।")
def rule_1_3_89(ctx=None):
    """
    1.3.89: न पादम्याङयमाङयसपरिमुहरुचिनृतिवदवसः ।
    """
    pass


@registry.register("1.3.90", text="वा क्यषः ।")
def rule_1_3_90(ctx=None):
    """
    1.3.90: वा क्यषः ।
    """
    pass


@registry.register("1.3.91", text="द्युच्यो लुङि ।")
def rule_1_3_91(ctx=None):
    """
    1.3.91: द्युच्यो लुङि ।
    """
    pass


@registry.register("1.3.92", text="वृद्भ्यः स्यसनोः ।")
def rule_1_3_92(ctx=None):
    """
    1.3.92: वृद्भ्यः स्यसनोः ।
    """
    pass


@registry.register("1.3.93", text="लुटि च क्लृपः ।")
def rule_1_3_93(ctx=None):
    """
    1.3.93: लुटि च क्लृपः ।
    """
    pass


@registry.register("1.4.1", text="आ कडारादेका संज्ञा ।")
def rule_1_4_1(ctx=None):
    """
    1.4.1: आ कडारादेका संज्ञा ।
    """
    pass


@registry.register("1.4.2", text="विप्रतिषेधे परं कार्यम् ।")
def rule_1_4_2(ctx=None):
    """
    1.4.2: विप्रतिषेधे परं कार्यम् ।
    """
    pass


@registry.register("1.4.3", text="यू ख्याख्यौ नदी ।")
def rule_1_4_3(ctx=None):
    """
    1.4.3: यू ख्याख्यौ नदी ।
    """
    pass


@registry.register("1.4.4", text="नेयडु‌वङ्खानावस्त्री ।")
def rule_1_4_4(ctx=None):
    """
    1.4.4: नेयडु‌वङ्खानावस्त्री ।
    """
    pass


@registry.register("1.4.5", text="वाऽऽमि ।")
def rule_1_4_5(ctx=None):
    """
    1.4.5: वाऽऽमि ।
    """
    pass


@registry.register("1.4.6", text="ङिति ह्रस्वश्च ।")
def rule_1_4_6(ctx=None):
    """
    1.4.6: ङिति ह्रस्वश्च ।
    """
    pass


@registry.register("1.4.7", text="शेषो घ्यसखि ।")
def rule_1_4_7(ctx=None):
    """
    1.4.7: शेषो घ्यसखि ।
    """
    pass


@registry.register("1.4.8", text="पतिः समास एव ।")
def rule_1_4_8(ctx=None):
    """
    1.4.8: पतिः समास एव ।
    """
    pass


@registry.register("1.4.9", text="षष्ठीयुक्तश्छन्दसि वा ।")
def rule_1_4_9(ctx=None):
    """
    1.4.9: षष्ठीयुक्तश्छन्दसि वा ।
    """
    pass


@registry.register("1.4.10", text="ह्रस्वं लघु ।")
def rule_1_4_10(ctx=None):
    """
    1.4.10: ह्रस्वं लघु ।
    """
    pass


@registry.register("1.4.11", text="संयोगे गुरु ।")
def rule_1_4_11(ctx=None):
    """
    1.4.11: संयोगे गुरु ।
    """
    pass


@registry.register("1.4.12", text="दीर्घ च ।")
def rule_1_4_12(ctx=None):
    """
    1.4.12: दीर्घ च ।
    """
    pass


@registry.register("1.4.13", text="यस्मात् प्रत्ययविधिस्तदादि प्रत्ययेऽङ्गम् ।")
def rule_1_4_13(ctx=None):
    """
    1.4.13: यस्मात् प्रत्ययविधिस्तदादि प्रत्ययेऽङ्गम् ।
    """
    pass


@registry.register("1.4.14", text="सुप्तिङन्तं पदम् ।")
def rule_1_4_14(ctx=None):
    """
    1.4.14: सुप्तिङन्तं पदम् ।
    """
    pass


@registry.register("1.4.15", text="नः क्ये ।")
def rule_1_4_15(ctx=None):
    """
    1.4.15: नः क्ये ।
    """
    pass


@registry.register("1.4.16", text="सिति च ।")
def rule_1_4_16(ctx=None):
    """
    1.4.16: सिति च ।
    """
    pass


@registry.register("1.4.17", text="स्वादिष्वसर्वनमस्थाने ।")
def rule_1_4_17(ctx=None):
    """
    1.4.17: स्वादिष्वसर्वनमस्थाने ।
    """
    pass


@registry.register("1.4.18", text="यचि भम् ।")
def rule_1_4_18(ctx=None):
    """
    1.4.18: यचि भम् ।
    """
    pass


@registry.register("1.4.19", text="तसौ मत्वर्थे ।")
def rule_1_4_19(ctx=None):
    """
    1.4.19: तसौ मत्वर्थे ।
    """
    pass


@registry.register("1.4.20", text="अयस्मयादीनि च्छन्दसि ।")
def rule_1_4_20(ctx=None):
    """
    1.4.20: अयस्मयादीनि च्छन्दसि ।
    """
    pass


@registry.register("1.4.21", text="बहुषु बहुवचनम् ।")
def rule_1_4_21(ctx=None):
    """
    1.4.21: बहुषु बहुवचनम् ।
    """
    pass


@registry.register("1.4.22", text="व्ह्येकयोर्द्विवचनैकवचने ।")
def rule_1_4_22(ctx=None):
    """
    1.4.22: व्ह्येकयोर्द्विवचनैकवचने ।
    """
    pass


@registry.register("1.4.23", text="कारके ।")
def rule_1_4_23(ctx=None):
    """
    1.4.23: कारके ।
    """
    pass


@registry.register("1.4.24", text="ध्रुवमपायेऽपादानम् ।")
def rule_1_4_24(ctx=None):
    """
    1.4.24: ध्रुवमपायेऽपादानम् ।
    """
    pass


@registry.register("1.4.25", text="भीत्रार्थानां भयहेतुः ।")
def rule_1_4_25(ctx=None):
    """
    1.4.25: भीत्रार्थानां भयहेतुः ।
    """
    pass


@registry.register("1.4.26", text="पराजेरसोढः ।")
def rule_1_4_26(ctx=None):
    """
    1.4.26: पराजेरसोढः ।
    """
    pass


@registry.register("1.4.27", text="वारणार्थानां ईप्सितः ।")
def rule_1_4_27(ctx=None):
    """
    1.4.27: वारणार्थानां ईप्सितः ।
    """
    pass


@registry.register("1.4.28", text="अन्तर्द्धा येनादर्शनमिच्छति ।")
def rule_1_4_28(ctx=None):
    """
    1.4.28: अन्तर्द्धा येनादर्शनमिच्छति ।
    """
    pass


@registry.register("1.4.29", text="आख्यातोपयोगे ।")
def rule_1_4_29(ctx=None):
    """
    1.4.29: आख्यातोपयोगे ।
    """
    pass


@registry.register("1.4.30", text="जनिकर्तुः प्रकृतिः ।")
def rule_1_4_30(ctx=None):
    """
    1.4.30: जनिकर्तुः प्रकृतिः ।
    """
    pass


@registry.register("1.4.31", text="भुवः प्रभवः ।")
def rule_1_4_31(ctx=None):
    """
    1.4.31: भुवः प्रभवः ।
    """
    pass


@registry.register("1.4.32", text="कर्मणा यमभिप्रैति स सम्प्रदानम् ।")
def rule_1_4_32(ctx=None):
    """
    1.4.32: कर्मणा यमभिप्रैति स सम्प्रदानम् ।
    """
    pass


@registry.register("1.4.33", text="रुच्यर्थानां प्रीयमाणः ।")
def rule_1_4_33(ctx=None):
    """
    1.4.33: रुच्यर्थानां प्रीयमाणः ।
    """
    pass


@registry.register("1.4.34", text="श्लाघहुङ्खाशपां ज्ञीप्स्यमानः ।")
def rule_1_4_34(ctx=None):
    """
    1.4.34: श्लाघहुङ्खाशपां ज्ञीप्स्यमानः ।
    """
    pass


@registry.register("1.4.35", text="धारेरुत्तमर्णः ।")
def rule_1_4_35(ctx=None):
    """
    1.4.35: धारेरुत्तमर्णः ।
    """
    pass


@registry.register("1.4.36", text="स्पृहेरीप्सितः ।")
def rule_1_4_36(ctx=None):
    """
    1.4.36: स्पृहेरीप्सितः ।
    """
    pass


@registry.register("1.4.37", text="क्रुधद्रुहेर्ष्याऽसूयार्थानां यं प्रति कोपः ।")
def rule_1_4_37(ctx=None):
    """
    1.4.37: क्रुधद्रुहेर्ष्याऽसूयार्थानां यं प्रति कोपः ।
    """
    pass


@registry.register("1.4.38", text="क्रुधद्रुहोरुपसृष्टयोः कर्म ।")
def rule_1_4_38(ctx=None):
    """
    1.4.38: क्रुधद्रुहोरुपसृष्टयोः कर्म ।
    """
    pass


@registry.register("1.4.39", text="राधीक्ष्योर्यस्य विप्रश्नः ।")
def rule_1_4_39(ctx=None):
    """
    1.4.39: राधीक्ष्योर्यस्य विप्रश्नः ।
    """
    pass


@registry.register("1.4.40", text="प्रत्यायां श्रुवः पूर्वस्य कर्ता ।")
def rule_1_4_40(ctx=None):
    """
    1.4.40: प्रत्यायां श्रुवः पूर्वस्य कर्ता ।
    """
    pass


@registry.register("1.4.41", text="अनुप्रतिगृणश्च ।")
def rule_1_4_41(ctx=None):
    """
    1.4.41: अनुप्रतिगृणश्च ।
    """
    pass


@registry.register("1.4.42", text="साधकतमं करणम् ।")
def rule_1_4_42(ctx=None):
    """
    1.4.42: साधकतमं करणम् ।
    """
    pass


@registry.register("1.4.43", text="दिवः कर्म च ।")
def rule_1_4_43(ctx=None):
    """
    1.4.43: दिवः कर्म च ।
    """
    pass


@registry.register("1.4.44", text="परिक्रयणे सम्प्रदानमन्यतरस्याम् ।")
def rule_1_4_44(ctx=None):
    """
    1.4.44: परिक्रयणे सम्प्रदानमन्यतरस्याम् ।
    """
    pass


@registry.register("1.4.45", text="आधारोऽधिकरणम् ।")
def rule_1_4_45(ctx=None):
    """
    1.4.45: आधारोऽधिकरणम् ।
    """
    pass


@registry.register("1.4.46", text="अधिशीङ्खाऽऽसां कर्म ।")
def rule_1_4_46(ctx=None):
    """
    1.4.46: अधिशीङ्खाऽऽसां कर्म ।
    """
    pass


@registry.register("1.4.47", text="अभिनिविशश्च ।")
def rule_1_4_47(ctx=None):
    """
    1.4.47: अभिनिविशश्च ।
    """
    pass


@registry.register("1.4.48", text="उपान्वध्याङ्कसः ।")
def rule_1_4_48(ctx=None):
    """
    1.4.48: उपान्वध्याङ्कसः ।
    """
    pass


@registry.register("1.4.49", text="कर्तुरीप्सिततमं कर्म ।")
def rule_1_4_49(ctx=None):
    """
    1.4.49: कर्तुरीप्सिततमं कर्म ।
    """
    pass


@registry.register("1.4.50", text="तथायुक्तं चानिप्सीतम् ।")
def rule_1_4_50(ctx=None):
    """
    1.4.50: तथायुक्तं चानिप्सीतम् ।
    """
    pass


@registry.register("1.4.51", text="अकथितं च ।")
def rule_1_4_51(ctx=None):
    """
    1.4.51: अकथितं च ।
    """
    pass


@registry.register("1.4.52", text="गतिबुद्धिप्रत्यवसानार्थशब्दकर्माकर्मकाणामणि कर्ता सणौ ।")
def rule_1_4_52(ctx=None):
    """
    1.4.52: गतिबुद्धिप्रत्यवसानार्थशब्दकर्माकर्मकाणामणि कर्ता सणौ ।
    """
    pass


@registry.register("1.4.53", text="हृक्रोरन्यतरस्याम् ।")
def rule_1_4_53(ctx=None):
    """
    1.4.53: हृक्रोरन्यतरस्याम् ।
    """
    pass


@registry.register("1.4.54", text="स्वतन्त्रः कर्ता ।")
def rule_1_4_54(ctx=None):
    """
    1.4.54: स्वतन्त्रः कर्ता ।
    """
    pass


@registry.register("1.4.55", text="तत्प्रयोजको हेतुश्च ।")
def rule_1_4_55(ctx=None):
    """
    1.4.55: तत्प्रयोजको हेतुश्च ।
    """
    pass


@registry.register("1.4.56", text="प्राग्रीश्वरान्निपातः ।")
def rule_1_4_56(ctx=None):
    """
    1.4.56: प्राग्रीश्वरान्निपातः ।
    """
    pass


@registry.register("1.4.57", text="चादयोऽसत्त्वे ।")
def rule_1_4_57(ctx=None):
    """
    1.4.57: चादयोऽसत्त्वे ।
    """
    pass


@registry.register("1.4.58", text="प्रादयः ।")
def rule_1_4_58(ctx=None):
    """
    1.4.58: प्रादयः ।
    """
    pass


@registry.register("1.4.59", text="उपसर्गाः क्रियायोगे ।")
def rule_1_4_59(ctx=None):
    """
    1.4.59: उपसर्गाः क्रियायोगे ।
    """
    pass


@registry.register("1.4.60", text="गतिश्च ।")
def rule_1_4_60(ctx=None):
    """
    1.4.60: गतिश्च ।
    """
    pass


@registry.register("1.4.61", text="ऊर्यादिच्चिडाचश्च ।")
def rule_1_4_61(ctx=None):
    """
    1.4.61: ऊर्यादिच्चिडाचश्च ।
    """
    pass


@registry.register("1.4.62", text="अनुकरणं चानितिपरम् ।")
def rule_1_4_62(ctx=None):
    """
    1.4.62: अनुकरणं चानितिपरम् ।
    """
    pass


@registry.register("1.4.63", text="आदरानादरयोः सदसती ।")
def rule_1_4_63(ctx=None):
    """
    1.4.63: आदरानादरयोः सदसती ।
    """
    pass


@registry.register("1.4.64", text="भूषणेऽलम् ।")
def rule_1_4_64(ctx=None):
    """
    1.4.64: भूषणेऽलम् ।
    """
    pass


@registry.register("1.4.65", text="अन्तरपरिग्रहे ।")
def rule_1_4_65(ctx=None):
    """
    1.4.65: अन्तरपरिग्रहे ।
    """
    pass


@registry.register("1.4.66", text="कणेमनसी श्रद्धाप्रतीघाते ।")
def rule_1_4_66(ctx=None):
    """
    1.4.66: कणेमनसी श्रद्धाप्रतीघाते ।
    """
    pass


@registry.register("1.4.67", text="पुरोऽव्ययम् ।")
def rule_1_4_67(ctx=None):
    """
    1.4.67: पुरोऽव्ययम् ।
    """
    pass


@registry.register("1.4.68", text="अस्तं च ।")
def rule_1_4_68(ctx=None):
    """
    1.4.68: अस्तं च ।
    """
    pass


@registry.register("1.4.69", text="अच्छ गत्यर्थवदेषु ।")
def rule_1_4_69(ctx=None):
    """
    1.4.69: अच्छ गत्यर्थवदेषु ।
    """
    pass


@registry.register("1.4.70", text="अदोऽनुपदेशे ।")
def rule_1_4_70(ctx=None):
    """
    1.4.70: अदोऽनुपदेशे ।
    """
    pass


@registry.register("1.4.71", text="तिरोऽन्तर्धी ।")
def rule_1_4_71(ctx=None):
    """
    1.4.71: तिरोऽन्तर्धी ।
    """
    pass


@registry.register("1.4.72", text="विभाषा कृञि ।")
def rule_1_4_72(ctx=None):
    """
    1.4.72: विभाषा कृञि ।
    """
    pass


@registry.register("1.4.73", text="उपाजेऽन्वाजे ।")
def rule_1_4_73(ctx=None):
    """
    1.4.73: उपाजेऽन्वाजे ।
    """
    pass


@registry.register("1.4.74", text="साक्षात्प्रभृतीनि च ।")
def rule_1_4_74(ctx=None):
    """
    1.4.74: साक्षात्प्रभृतीनि च ।
    """
    pass


@registry.register("1.4.75", text="अनत्याधान उरसिमनसी ।")
def rule_1_4_75(ctx=None):
    """
    1.4.75: अनत्याधान उरसिमनसी ।
    """
    pass


@registry.register("1.4.76", text="मध्येपदेनिवचने च ।")
def rule_1_4_76(ctx=None):
    """
    1.4.76: मध्येपदेनिवचने च ।
    """
    pass


@registry.register("1.4.77", text="नित्यं हस्ते पाणावुपयमने ।")
def rule_1_4_77(ctx=None):
    """
    1.4.77: नित्यं हस्ते पाणावुपयमने ।
    """
    pass


@registry.register("1.4.78", text="प्राध्वं बन्धने ।")
def rule_1_4_78(ctx=None):
    """
    1.4.78: प्राध्वं बन्धने ।
    """
    pass


@registry.register("1.4.79", text="जीविकोपनिषदावौपम्ये ।")
def rule_1_4_79(ctx=None):
    """
    1.4.79: जीविकोपनिषदावौपम्ये ।
    """
    pass


@registry.register("1.4.80", text="ते प्राग्धातोः ।")
def rule_1_4_80(ctx=None):
    """
    1.4.80: ते प्राग्धातोः ।
    """
    pass


@registry.register("1.4.81", text="छन्दसि परेऽपि ।")
def rule_1_4_81(ctx=None):
    """
    1.4.81: छन्दसि परेऽपि ।
    """
    pass


@registry.register("1.4.82", text="व्यवहिताश्च ।")
def rule_1_4_82(ctx=None):
    """
    1.4.82: व्यवहिताश्च ।
    """
    pass


@registry.register("1.4.83", text="कर्मप्रवचनीयाः ।")
def rule_1_4_83(ctx=None):
    """
    1.4.83: कर्मप्रवचनीयाः ।
    """
    pass


@registry.register("1.4.84", text="अनुर्लक्षणे ।")
def rule_1_4_84(ctx=None):
    """
    1.4.84: अनुर्लक्षणे ।
    """
    pass


@registry.register("1.4.85", text="तृतीयाऽर्थे ।")
def rule_1_4_85(ctx=None):
    """
    1.4.85: तृतीयाऽर्थे ।
    """
    pass


@registry.register("1.4.86", text="हीने ।")
def rule_1_4_86(ctx=None):
    """
    1.4.86: हीने ।
    """
    pass


@registry.register("1.4.87", text="उपोऽधिके च ।")
def rule_1_4_87(ctx=None):
    """
    1.4.87: उपोऽधिके च ।
    """
    pass


@registry.register("1.4.88", text="अपपरी वर्जने ।")
def rule_1_4_88(ctx=None):
    """
    1.4.88: अपपरी वर्जने ।
    """
    pass


@registry.register("1.4.89", text="आङ् मर्यादावचने ।")
def rule_1_4_89(ctx=None):
    """
    1.4.89: आङ् मर्यादावचने ।
    """
    pass


@registry.register("1.4.90", text="लक्षणेत्थम्भूताख्यानभागवीप्सासु प्रतिपर्यनवः ।")
def rule_1_4_90(ctx=None):
    """
    1.4.90: लक्षणेत्थम्भूताख्यानभागवीप्सासु प्रतिपर्यनवः ।
    """
    pass


@registry.register("1.4.91", text="अभिरभागे ।")
def rule_1_4_91(ctx=None):
    """
    1.4.91: अभिरभागे ।
    """
    pass


@registry.register("1.4.92", text="प्रतिः प्रतिनिधिप्रतिदानयोः ।")
def rule_1_4_92(ctx=None):
    """
    1.4.92: प्रतिः प्रतिनिधिप्रतिदानयोः ।
    """
    pass


@registry.register("1.4.93", text="अधिपरी अनर्थकौ ।")
def rule_1_4_93(ctx=None):
    """
    1.4.93: अधिपरी अनर्थकौ ।
    """
    pass


@registry.register("1.4.94", text="सुः पूजायाम् ।")
def rule_1_4_94(ctx=None):
    """
    1.4.94: सुः पूजायाम् ।
    """
    pass


@registry.register("1.4.95", text="अतिरतिक्रमणे च ।")
def rule_1_4_95(ctx=None):
    """
    1.4.95: अतिरतिक्रमणे च ।
    """
    pass


@registry.register("1.4.96", text="अपिः पदार्थसम्भावनान्ववसर्गगर्हासमुच्चयेषु ।")
def rule_1_4_96(ctx=None):
    """
    1.4.96: अपिः पदार्थसम्भावनान्ववसर्गगर्हासमुच्चयेषु ।
    """
    pass


@registry.register("1.4.97", text="अधिरीश्वरे ।")
def rule_1_4_97(ctx=None):
    """
    1.4.97: अधिरीश्वरे ।
    """
    pass


@registry.register("1.4.98", text="विभाषा कृञि ।")
def rule_1_4_98(ctx=None):
    """
    1.4.98: विभाषा कृञि ।
    """
    pass


@registry.register("1.4.99", text="लः परस्मैपदम् ।")
def rule_1_4_99(ctx=None):
    """
    1.4.99: लः परस्मैपदम् ।
    """
    pass


@registry.register("1.4.100", text="तङानावात्मनेपदम् ।")
def rule_1_4_100(ctx=None):
    """
    1.4.100: तङानावात्मनेपदम् ।
    """
    pass


@registry.register("1.4.101", text="तिङस्त्रीणि त्रीणि प्रथममध्यमोत्तमाः ।")
def rule_1_4_101(ctx=None):
    """
    1.4.101: तिङस्त्रीणि त्रीणि प्रथममध्यमोत्तमाः ।
    """
    pass


@registry.register("1.4.102", text="तान्येकवचनद्विवचनबहुवचनान्येकशः ।")
def rule_1_4_102(ctx=None):
    """
    1.4.102: तान्येकवचनद्विवचनबहुवचनान्येकशः ।
    """
    pass


@registry.register("1.4.103", text="सुपः ।")
def rule_1_4_103(ctx=None):
    """
    1.4.103: सुपः ।
    """
    pass


@registry.register("1.4.104", text="विभक्तिश्च ।")
def rule_1_4_104(ctx=None):
    """
    1.4.104: विभक्तिश्च ।
    """
    pass


@registry.register("1.4.105", text="युष्मद्युपपदे समानाधिकरणे स्थानिन्यपि मध्यमः ।")
def rule_1_4_105(ctx=None):
    """
    1.4.105: युष्मद्युपपदे समानाधिकरणे स्थानिन्यपि मध्यमः ।
    """
    pass


@registry.register("1.4.106", text="प्रहासे च मन्योपपदे मन्यतेरुत्तम एकवच्च ।")
def rule_1_4_106(ctx=None):
    """
    1.4.106: प्रहासे च मन्योपपदे मन्यतेरुत्तम एकवच्च ।
    """
    pass


@registry.register("1.4.107", text="अस्मद्युत्तमः ।")
def rule_1_4_107(ctx=None):
    """
    1.4.107: अस्मद्युत्तमः ।
    """
    pass


@registry.register("1.4.108", text="शेषे प्रथमः ।")
def rule_1_4_108(ctx=None):
    """
    1.4.108: शेषे प्रथमः ।
    """
    pass


@registry.register("1.4.109", text="परः संनिकर्षः संहिता ।")
def rule_1_4_109(ctx=None):
    """
    1.4.109: परः संनिकर्षः संहिता ।
    """
    pass


@registry.register("1.4.110", text="विरामोऽवसानम् ।")
def rule_1_4_110(ctx=None):
    """
    1.4.110: विरामोऽवसानम् ।
    """
    pass



"""Tests for panini-nlp package."""

import unittest
from panini_nlp.sandhi import SandhiEngine
from panini_nlp.morphology import MorphologicalAnalyzer
from panini_nlp.semantics import SemanticParser
from panini_nlp.chandas import ChandasAnalyzer
from panini_nlp.samasa import SamasaAnalyzer
from panini_nlp.validator import SanskritValidator


class TestSandhi(unittest.TestCase):
    def setUp(self):
        self.engine = SandhiEngine()

    def test_dirgha_sandhi(self):
        """6.1.101 — अ + अ → आ"""
        result = self.engine.apply("अ", "अग्नि")
        self.assertIsNotNone(result.rule_applied)
        self.assertEqual(result.rule_applied.id, "6.1.101")

    def test_guna_sandhi(self):
        """6.1.87 — अ + इ → ए"""
        result = self.engine.apply("अ", "इन्द्रः")
        self.assertIsNotNone(result.rule_applied)
        self.assertEqual(result.rule_applied.id, "6.1.87")

    def test_explain(self):
        """explain() should return explanations for sandhi-eligible text."""
        explanations = self.engine.explain("देवेन्द्रः")
        # Should detect at least potential sandhi
        self.assertIsInstance(explanations, list)

    def test_list_rules(self):
        """Should have at least 4 rules."""
        self.assertGreaterEqual(len(self.engine.rules), 4)


class TestMorphology(unittest.TestCase):
    def setUp(self):
        self.analyzer = MorphologicalAnalyzer()

    def test_nominative(self):
        """Recognize nominative singular -ः."""
        results = self.analyzer.analyze("रामः")
        self.assertTrue(len(results) > 0)
        noms = [r for r in results if r.vibhakti == "Nominative"]
        self.assertTrue(len(noms) > 0)

    def test_accusative(self):
        """Recognize accusative singular -म्."""
        results = self.analyzer.analyze("वनम्")
        self.assertTrue(len(results) > 0)
        accs = [r for r in results if r.vibhakti == "Accusative"]
        self.assertTrue(len(accs) > 0)

    def test_verb(self):
        """Recognize verb ending -ति."""
        results = self.analyzer.analyze("गच्छति")
        self.assertTrue(len(results) > 0)
        verbs = [r for r in results if r.category == "Tiṅanta"]
        self.assertTrue(len(verbs) > 0)


class TestSemantics(unittest.TestCase):
    def setUp(self):
        self.parser = SemanticParser()

    def test_parse_sentence(self):
        """Parse a basic sentence into a kāraka graph."""
        graph = self.parser.parse("रामः वनम् गच्छति")
        self.assertIsNotNone(graph)
        self.assertGreater(len(graph.nodes), 0)

    def test_graph_has_edges(self):
        """A multi-word sentence should have edges."""
        graph = self.parser.parse("रामः वनम् गच्छति")
        self.assertGreater(len(graph.edges), 0)


class TestChandas(unittest.TestCase):
    def setUp(self):
        self.analyzer = ChandasAnalyzer()

    def test_analyze_iast(self):
        """Analyze IAST text for prosody."""
        result = self.analyzer.analyze("dharmasya tattvam")
        self.assertGreater(result.syllable_count, 0)
        self.assertIn(result.pattern[0], ["0", "1"])

    def test_prastara(self):
        """Generate all patterns of length n."""
        patterns = self.analyzer.prastara(3)
        self.assertEqual(len(patterns), 8)  # 2^3

    def test_nashtam_uddishtam_roundtrip(self):
        """Naṣṭam and Uddiṣṭam should be inverses."""
        pattern = "10110"
        idx = self.analyzer.uddishtam(pattern)
        restored = self.analyzer.nashtam(idx, len(pattern))
        self.assertEqual(pattern, restored)


class TestSamasa(unittest.TestCase):
    def setUp(self):
        self.analyzer = SamasaAnalyzer()

    def test_bahuvrihi(self):
        """Detect Bahuvrīhi compound."""
        result = self.analyzer.analyze("pītāmbaram")
        # May or may not detect depending on substring matching
        if result:
            self.assertIn("Bahuvrīhi", result.compound_type)

    def test_avyayibhava(self):
        """Detect Avyayībhāva prefix."""
        result = self.analyzer.analyze("yathāvidhi")
        self.assertIsNotNone(result)
        self.assertIn("Avyayībhāva", result.compound_type)


class TestValidator(unittest.TestCase):
    def setUp(self):
        self.validator = SanskritValidator()

    def test_validate_basic(self):
        """Full pipeline on a basic sentence."""
        result = self.validator.validate("रामः वनम् गच्छति")
        self.assertTrue(result.is_valid)
        self.assertGreater(len(result.suggestions), 0)

    def test_validate_returns_result(self):
        """Result should have expected attributes."""
        result = self.validator.validate("धर्मक्षेत्रे")
        self.assertIsInstance(result.grammar_patterns, dict)
        self.assertIn("sandhi", result.grammar_patterns)

    def test_empty_input(self):
        """Empty input should return is_valid=False."""
        result = self.validator.validate("")
        self.assertFalse(result.is_valid)

    def test_validate_document_verse_split(self):
        """Document-level analysis should split and aggregate."""
        text = "रामः वनम् गच्छति। देवः पठति॥"
        doc = self.validator.validate_document(text, split_mode="verse")
        self.assertEqual(doc["segment_count"], 2)
        self.assertIn("summary", doc)
        self.assertIn("segments", doc)
        self.assertEqual(len(doc["segments"]), 2)

    def test_validate_document_line_split(self):
        """Line mode should split on newlines."""
        text = "रामः वनम् गच्छति\nदेवः पठति"
        doc = self.validator.validate_document(text, split_mode="line")
        self.assertEqual(doc["segment_count"], 2)

    def test_validate_document_invalid_mode(self):
        """Invalid split mode should raise ValueError."""
        with self.assertRaises(ValueError):
            self.validator.validate_document("रामः", split_mode="chunk")


if __name__ == "__main__":
    unittest.main()
